@@ -30,11 +30,18 @@ from cylc.flow.broadcast_report import (
 from cylc.flow.cfgspec.workflow import SPEC
 from cylc.flow.cycling.loader import get_point, standardise_point_string
 from cylc.flow.exceptions import PointParsingError
-from cylc.flow.parsec.util import listjoin
+from cylc.flow.parsec.util import listjoin, pdeepcopy, poverride
 from cylc.flow.parsec.validate import BroadcastConfigValidator
+from cylc.flow.run_modes import WORKFLOW_ONLY_MODES
+from cylc.flow.platforms import (
+    fail_if_platform_and_host_conflict,
+    PlatformLookupError,
+)
+from cylc.flow.util import uniq
 
 if TYPE_CHECKING:
     from cylc.flow.id import Tokens
+    from cylc.flow.task_proxy import TaskProxy
 
 
 ALL_CYCLE_POINTS_STRS = ["*", "all-cycle-points", "all-cycles"]
@@ -61,9 +68,11 @@ class BroadcastMgr:
 
     REC_SECTION = re.compile(r"\[([^\]]+)\]")
 
-    def __init__(self, workflow_db_mgr, data_store_mgr):
-        self.workflow_db_mgr = workflow_db_mgr
-        self.data_store_mgr = data_store_mgr
+    def __init__(self, schd):
+        self.schd = schd
+        self.workflow_run_mode = schd.get_run_mode()
+        self.workflow_db_mgr = schd.workflow_db_mgr
+        self.data_store_mgr = schd.data_store_mgr
         self.linearized_ancestors = {}
         self.broadcasts = {}
         self.ext_triggers = {}  # Can use collections.Counter in future
@@ -142,7 +151,7 @@ class BroadcastMgr:
             LOG.error(get_broadcast_bad_options_report(bad_options))
         if modified_settings:
             self.data_store_mgr.delta_broadcast()
-        return modified_settings, bad_options
+        return uniq(modified_settings), bad_options
 
     def expire_broadcast(self, cutoff=None, **kwargs):
         """Clear all broadcasts targeting cycle points earlier than cutoff."""
@@ -179,6 +188,18 @@ class BroadcastMgr:
                     addict(ret, self.broadcasts[cycle][namespace])
         return ret
 
+    def get_updated_rtconfig(self, itask: 'TaskProxy') -> dict:
+        """Retrieve updated rtconfig for a single task proxy"""
+        overrides = self.get_broadcast(
+            itask.tokens
+        )
+        if overrides:
+            rtconfig = pdeepcopy(itask.tdef.rtconfig)
+            poverride(rtconfig, overrides, prepend=True)
+        else:
+            rtconfig = itask.tdef.rtconfig
+        return rtconfig
+
     def load_db_broadcast_states(self, row_idx, row):
         """Load broadcast variables from runtime DB broadcast states row."""
         if row_idx == 0:
@@ -263,42 +284,86 @@ class BroadcastMgr:
           bad_options is as described in the docstring for self.clear().
         """
         modified_settings = []
-        bad_point_strings = []
-        bad_namespaces = []
+        bad_settings = []
+        bad_point_strings = set()
+        bad_namespaces = set()
 
         with self.lock:
-            for setting in settings:
-                for point_string in point_strings:
+            for setting in settings or []:
+                # Coerce setting to cylc runtime object,
+                # i.e. str to  DurationFloat.
+                coerced_setting = deepcopy(setting)
+                try:
+                    BroadcastConfigValidator().validate(
+                        coerced_setting,
+                        SPEC['runtime']['__MANY__'],
+                    )
+                except Exception as exc:
+                    LOG.error(exc)
+                    bad_settings.append(setting)
+                    continue
+
+                # Skip and warn if a run mode is broadcast to a workflow
+                # running in simulation or dummy mode.
+                if (
+                    'run mode' in coerced_setting
+                    and self.workflow_run_mode.value in WORKFLOW_ONLY_MODES
+                ):
+                    LOG.warning(
+                        f'Broadcasting {coerced_setting} to a workflow'
+                        f' running in {self.workflow_run_mode.value} mode'
+                        ' will have no effect, and will not be actioned.'
+                    )
+                    bad_settings.append(setting)
+                    continue
+
+                for point_string in point_strings or []:
                     # Standardise the point and check its validity.
                     bad_point = False
                     try:
                         point_string = standardise_point_string(point_string)
+
                     except PointParsingError:
                         if point_string != '*':
-                            bad_point_strings.append(point_string)
+                            bad_point_strings.add(point_string)
                             bad_point = True
                     if not bad_point and point_string not in self.broadcasts:
                         self.broadcasts[point_string] = {}
-                    for namespace in namespaces:
+                    for namespace in namespaces or []:
                         if namespace not in self.linearized_ancestors:
-                            bad_namespaces.append(namespace)
+                            bad_namespaces.add(namespace)
                         elif not bad_point:
+                            # Check broadcast against config and against
+                            # existing broadcasts:
+                            newconfig = pdeepcopy(self.schd.config.get_config(
+                                ['runtime', namespace]
+                            ))
+                            poverride(
+                                newconfig,
+                                self.broadcasts.get(point_string, {})
+                                .get(namespace, {})
+                            )
+                            if self.bc_mixes_old_and_new_platform_settings(
+                                newconfig,
+                                namespace,
+                                coerced_setting,
+                            ):
+                                bad_settings.append(setting)
+                                continue
+
                             if namespace not in self.broadcasts[point_string]:
                                 self.broadcasts[point_string][namespace] = {}
+
                             # Keep saved/reported setting as workflow
-                            # config format.
+                            # config format:
                             modified_settings.append(
-                                (point_string, namespace, deepcopy(setting))
-                            )
-                            # Coerce setting to cylc runtime object,
-                            # i.e. str to  DurationFloat.
-                            BroadcastConfigValidator().validate(
-                                setting,
-                                SPEC['runtime']['__MANY__']
+                                (point_string, namespace, setting)
                             )
+
+                            # Apply the broadcast with the "coerced" format:
                             addict(
                                 self.broadcasts[point_string][namespace],
-                                setting
+                                coerced_setting,
                             )
 
         # Log the broadcast
@@ -306,13 +371,32 @@ class BroadcastMgr:
         LOG.info(get_broadcast_change_report(modified_settings))
 
         bad_options = {}
+        if bad_settings:
+            bad_options["settings"] = uniq(bad_settings)
         if bad_point_strings:
-            bad_options["point_strings"] = bad_point_strings
+            bad_options["point_strings"] = sorted(bad_point_strings)
         if bad_namespaces:
-            bad_options["namespaces"] = bad_namespaces
+            bad_options["namespaces"] = sorted(bad_namespaces)
         if modified_settings:
             self.data_store_mgr.delta_broadcast()
-        return modified_settings, bad_options
+        return uniq(modified_settings), bad_options
+
+    @staticmethod
+    def bc_mixes_old_and_new_platform_settings(
+        task_config, namespace, coerced_setting
+    ):
+        """Check for combination of old ([remote]host) and new (platform)
+        settings in the task config as it will be after merger.
+        """
+        task_config.update(coerced_setting)
+        try:
+            fail_if_platform_and_host_conflict(
+                task_config, namespace
+            )
+            return False
+        except PlatformLookupError as exc:
+            LOG.error('Cannot apply broadcast:\n' + '\n    '.join(exc.args))
+            return True
 
     @staticmethod
     def _cancel_keys_in_prunes(prunes, cancel_keys):
