@@ -19,11 +19,12 @@ import re
 import contextlib
 
 from typing import (
-    Set,
     Dict,
     List,
+    Optional,
+    Set,
     Tuple,
-    Optional
+    Union
 )
 
 import cylc.flow.flags
@@ -32,6 +33,7 @@ from cylc.flow.param_expand import GraphExpander
 from cylc.flow.task_id import TaskID
 from cylc.flow.task_trigger import TaskTrigger
 from cylc.flow.task_outputs import (
+    TASK_OUTPUT_EXPIRED,
     TASK_OUTPUT_SUCCEEDED,
     TASK_OUTPUT_STARTED,
     TASK_OUTPUT_FAILED,
@@ -40,6 +42,8 @@ from cylc.flow.task_outputs import (
     TASK_OUTPUT_SUBMIT_FAILED
 )
 from cylc.flow.task_qualifiers import (
+    QUAL_FAM_EXPIRE_ALL,
+    QUAL_FAM_EXPIRE_ANY,
     QUAL_FAM_SUCCEED_ALL,
     QUAL_FAM_SUCCEED_ANY,
     QUAL_FAM_FAIL_ALL,
@@ -85,10 +89,10 @@ class GraphParser:
     store dependencies for the whole workflow (call parse_graph multiple times
     and key results by graph section).
 
-    The general form of a dependency is "EXPRESSION => NODE", where:
-        * On the right, NODE is a task or family name
+    The general form of a dependency is "LHS => RHS", where:
         * On the left, an EXPRESSION of nodes involving parentheses, and
           logical operators '&' (AND), and '|' (OR).
+        * On the right, an EXPRESSION of nodes NOT involving '|'
         * Node names may be parameterized (any number of parameters):
             NODE<i,j,k>
             NODE<i=0,j,k>  # specific parameter value
@@ -100,8 +104,44 @@ class GraphParser:
             NODE(<REMOTE-WORKFLOW-QUALIFIER>)(:QUALIFIER)
         * Outputs (boo:x) are ignored as triggers on the RHS to allow chaining:
             "foo => bar:x => baz & qux"
-    """
 
+    Chained triggers get decomposed into pairs for processing, e.g.:
+        x  # lone node
+        a | b => c & d => e
+    becomes:
+        [None, x],
+        [None, a],
+        [None, b],
+        [a|b, c&d],  --> [a|b, c], [a|b, d]
+        [c&d, e],   --> [c, e], [d, e]
+    (Lone nodes and left-side nodes make [None, left] for auto-triggering.)
+
+    LEFT sides are TASK OUTPUTS (a plain name is short for "task:succeeded"):
+        a:x & b? & c => d
+    means:
+        a:x & b:succeeded? & c:succeeded => d
+
+    RIGHT sides are just TASKS to trigger when the left side outputs complete:
+        [left] => d  # does NOT imply d:succeeded is required
+
+    But output optionality can be *explicitly* set on the right, if you like:
+        [left] => d?
+        [left] => e:x
+    means
+        [left] => d  # AND d:succeeded is optional
+        [left] => e  # AND e:x is required
+
+    How the graph parser determines output optionality:
+       In chained triggers every node appears on the right of a pair, so we
+       only need rights to set (and check consitency of) optional outputs.
+          x                # [None, x] ... x is end-of-chain
+          a => b => c      # [None, a], [a, b], [b, c] ... c is end-of-chain
+
+       But note we infer :succeeded (for plain task names) except at the end
+       of a chain that is not a lone node (i.e. for x, but not c).
+       i.e.: if NOT end-of-chain OR left is None.
+
+    """
     CYLC7_COMPAT = "CYLC 7 BACK-COMPAT"
 
     OP_AND = '&'
@@ -123,6 +163,8 @@ class GraphParser:
     # E.g. QUAL_FAM_START_ALL: (TASK_OUTPUT_STARTED, True) simply maps
     #   "FAM:start-all" to "MEMBER:started" and "-all" (all members).
     fam_to_mem_trigger_map: Dict[str, Tuple[str, bool]] = {
+        QUAL_FAM_EXPIRE_ALL: (TASK_OUTPUT_EXPIRED, True),
+        QUAL_FAM_EXPIRE_ANY: (TASK_OUTPUT_EXPIRED, False),
         QUAL_FAM_START_ALL: (TASK_OUTPUT_STARTED, True),
         QUAL_FAM_START_ANY: (TASK_OUTPUT_STARTED, False),
         QUAL_FAM_SUCCEED_ALL: (TASK_OUTPUT_SUCCEEDED, True),
@@ -139,6 +181,8 @@ class GraphParser:
 
     # Map family pseudo triggers to affected member outputs.
     fam_to_mem_output_map: Dict[str, List[str]] = {
+        QUAL_FAM_EXPIRE_ANY: [TASK_OUTPUT_EXPIRED],
+        QUAL_FAM_EXPIRE_ALL: [TASK_OUTPUT_EXPIRED],
         QUAL_FAM_START_ANY: [TASK_OUTPUT_STARTED],
         QUAL_FAM_START_ALL: [TASK_OUTPUT_STARTED],
         QUAL_FAM_SUCCEED_ANY: [TASK_OUTPUT_SUCCEEDED],
@@ -160,6 +204,7 @@ class GraphParser:
     _RE_OFFSET = r'\[[\w\-\+\^:]+\]'
     _RE_QUAL = QUALIFIER + r'[\w\-]+'  # task or fam trigger
     _RE_OPT = r'\??'  # optional output indicator
+    _RE_ANDOR = re.compile(r'\s*[&|]\s*')
 
     REC_QUAL = re.compile(_RE_QUAL)
 
@@ -243,6 +288,7 @@ class GraphParser:
         rf"""
         (!)?           # suicide mark
         ({_RE_NODE})   # node name
+        ({_RE_OFFSET})?  # cycle point offset
         ({_RE_QUAL})?  # trigger qualifier
         ({_RE_OPT})?   # optional output indicator
         """,
@@ -254,7 +300,8 @@ class GraphParser:
         family_map: Optional[Dict[str, List[str]]] = None,
         parameters: Optional[Dict] = None,
         task_output_opt:
-            Optional[Dict[Tuple[str, str], Tuple[bool, bool, bool]]] = None
+            Optional[Dict[Tuple[str, str], Tuple[bool, bool, bool]]] = None,
+        expire_triggers: bool = False,
     ) -> None:
         """Initialize the graph string parser.
 
@@ -273,6 +320,8 @@ class GraphParser:
         self.triggers: Dict = {}
         self.original: Dict = {}
         self.workflow_state_polling_tasks: Dict = {}
+        self.expire_triggers = expire_triggers
+        self.end_of_chain_nodes: set[str] = set()
 
         # Record task outputs as optional or required:
         #   {(name, output): (is_optional, is_member)}
@@ -338,7 +387,7 @@ class GraphParser:
                         raise GraphParseError(
                             f"Dangling {seq}:"
                             f"{this_line}"
-                        )
+                        ) from None
             part_lines.append(this_line)
 
             # Check that a continuation sequence doesn't end this line and
@@ -372,11 +421,10 @@ class GraphParser:
             full_line = self.__class__.REC_WORKFLOW_STATE.sub(repl, full_line)
             for item in repl.match_groups:
                 l_task, r_all, r_workflow, r_task, r_status = item
-                if r_status:
-                    r_status = r_status.strip(self.__class__.QUALIFIER)
-                    r_status = TaskTrigger.standardise_name(r_status)
-                else:
-                    r_status = TASK_OUTPUT_SUCCEEDED
+                if r_status is not None:
+                    r_status = TaskTrigger.standardise_name(
+                        r_status.strip(self.__class__.QUALIFIER)
+                    )
                 self.workflow_state_polling_tasks[l_task] = (
                     r_workflow, r_task, r_status, r_all
                 )
@@ -461,8 +509,30 @@ class GraphParser:
             for i in range(0, len(chain) - 1):
                 pairs.add((chain[i], chain[i + 1]))
 
-        for pair in pairs:
-            self._proc_dep_pair(pair)
+            # Record end of chain nodes (can be multiple with &)
+            self.end_of_chain_nodes.update(
+                chain[-1].split(self.__class__.OP_AND)
+            )
+
+        # Get a set of RH nodes which are not at the LH of another pair:
+        # terminals = {p[1] for p in pairs}.difference({p[0] for p in pairs})
+
+        check_terminals: Dict[str, str] = {}
+        lefts: Set[str] = set()
+        rights: Set[str] = set()
+
+        for pair in sorted(pairs, key=lambda p: str(p[0])):
+            self._proc_dep_pair(pair, check_terminals, lefts, rights)
+
+        self.terminals = rights.difference(lefts)
+        for right in self.terminals:
+            left = check_terminals.get(right)
+            if left:
+                raise GraphParseError(
+                    'Invalid cycle point offsets only on right hand'
+                    ' side of dependency (must be on left hand side):'
+                    f'{left} => {right}'
+                )
 
     @classmethod
     def _report_invalid_lines(cls, lines: List[str]) -> None:
@@ -492,19 +562,25 @@ class GraphParser:
 
     def _proc_dep_pair(
         self,
-        pair: Tuple[Optional[str], str]
+        pair: Tuple[Optional[str], str],
+        check_terminals: Dict[str, str],
+        _lefts: Set[str],
+        _rights: Set[str],
     ) -> None:
         """Process a single dependency pair 'left => right'.
 
-        'left' can be a logical expression of qualified node names.
-        'left' can be None, when triggering a left-side or lone node.
-        'left' can be "", if null task name in graph error (a => => b).
-        'right' can be one or more node names joined by AND.
-        'right' can't be None or "".
         A node is an xtrigger, or a task or a family name.
         A qualified name is NAME([CYCLE-POINT-OFFSET])(:QUALIFIER).
-        Trigger qualifiers, but not cycle offsets, are ignored on the right to
-        allow chaining.
+
+        Args:
+            pair:
+                'left' can be a logical expression of qualified node names.
+                'left' can be None, when triggering a left-side or lone node.
+                'left' can be "", if null task name in graph error (a => => b).
+                'right' can be one or more node names joined by AND.
+                'right' can't be None or "".
+            terminals:
+                Nodes which are _only_ on the RH end of chains.
         """
         left, right = pair
         # Raise error for right-hand-side OR operators.
@@ -517,15 +593,16 @@ class GraphParser:
                 "Suicide markers must be"
                 f" on the right of a trigger: {left}")
 
-        # Ignore cycle point offsets on the right side.
-        # (Note we can't ban this; all nodes get process as left and right.)
-        if '[' in right:
-            return
-
         # Check that parentheses match.
+        mismatch_msg = 'Mismatched parentheses in: "{}"'
         if left and left.count("(") != left.count(")"):
-            raise GraphParseError(
-                "Mismatched parentheses in: \"" + left + "\"")
+            raise GraphParseError(mismatch_msg.format(left))
+        if right.count("(") != right.count(")"):
+            raise GraphParseError(mismatch_msg.format(right))
+
+        # Raise error for cycle point offsets at the end of chains
+        if '[' in right and left:
+            check_terminals[right] = left
 
         # Split right side on AND.
         rights = right.split(self.__class__.OP_AND)
@@ -533,26 +610,28 @@ class GraphParser:
             raise GraphParseError(
                 f"Null task name in graph: {left} => {right}")
 
+        lefts: Union[List[str], List[Optional[str]]]
         if not left or (self.__class__.OP_OR in left or '(' in left):
-            # Treat conditional or bracketed expressions as a single entity.
+            # Treat conditional or parenthesised expressions as a single entity
             # Can get [None] or [""] here
-            lefts: List[Optional[str]] = [left]
+            lefts = [left]
         else:
             # Split non-conditional left-side expressions on AND.
             # Can get [""] here too
-            # TODO figure out how to handle this wih mypy:
-            #   assign List[str] to List[Optional[str]]
-            lefts = left.split(self.__class__.OP_AND)  # type: ignore
+            lefts = left.split(self.__class__.OP_AND)
         if '' in lefts or left and not all(lefts):
             raise GraphParseError(
                 f"Null task name in graph: {left} => {right}")
 
+        _rights.update(*([rights] or []))
+
         for left in lefts:
             # Extract information about all nodes on the left.
-
             if left:
                 info = self.__class__.REC_NODES.findall(left)
                 expr = left
+                for _left in info:
+                    _lefts.add(''.join(_left))
 
             else:
                 # There is no left-hand-side task.
@@ -585,6 +664,10 @@ class GraphParser:
                         expr = re.sub(this, that, expr)
                 else:
                     # Make success triggers explicit.
+                    if name in self.family_map:
+                        raise GraphParseError(
+                            f"Family trigger required: {left} => {right}"
+                        )
                     n_trig = TASK_OUTPUT_SUCCEEDED
                     if offset:
                         this = r'\b%s\b%s(?!:)' % (
@@ -615,12 +698,13 @@ class GraphParser:
                     except KeyError:
                         # "FAM:bad => foo" in LHS (includes "FAM => bar" too).
                         raise GraphParseError(
-                            f"Illegal family trigger in {expr}")
+                            f"Illegal family trigger in {expr}"
+                        ) from None
                 else:
                     # Not a family.
                     if trig in self.__class__.fam_to_mem_trigger_map:
                         raise GraphParseError(
-                            "family trigger on non-family namespace {expr}")
+                            f"family trigger on non-family namespace {expr}")
 
             # remove '?' from expr (not needed in logical trigger evaluation)
             expr = re.sub(self.__class__._RE_OPT, '', expr)
@@ -709,6 +793,10 @@ class GraphParser:
         self.original.setdefault(name, {})
         self.original[name][expr] = orig_expr
 
+        if suicide and self.expire_triggers:
+            # Make expiry optional for suicide triggered tasks.
+            self._set_output_opt(name, TASK_OUTPUT_EXPIRED, True, False, False)
+
     def _set_output_opt(
         self,
         name: str,
@@ -736,6 +824,15 @@ class GraphParser:
         if suicide:
             return
 
+        if (
+            output in {TASK_OUTPUT_EXPIRED, TASK_OUTPUT_SUBMIT_FAILED}
+            and not optional
+        ):
+            # ":expire" and ":submit-fail" cannot be required
+            # proposal point 4:
+            # https://cylc.github.io/cylc-admin/proposal-optional-output-extension.html#proposal
+            raise GraphParseError(f"{name}:{output} must be optional")
+
         if output == TASK_OUTPUT_FINISHED:
             # Interpret :finish pseudo-output
             if optional:
@@ -746,6 +843,7 @@ class GraphParser:
             for outp in [TASK_OUTPUT_SUCCEEDED, TASK_OUTPUT_FAILED]:
                 self._set_output_opt(
                     name, outp, optional, suicide, fam_member)
+            return
 
         try:
             prev_optional, prev_default, prev_fixed = (
@@ -847,9 +945,14 @@ class GraphParser:
                 trigs += [f"{name}{offset}:{trigger}"]
 
         for right in rights:
+            right = right.strip('()')  # parentheses don't matter
             m = self.__class__.REC_RHS_NODE.match(right)
-            # This will match, bad nodes are detected earlier (type ignore):
-            suicide_char, name, output, opt_char = m.groups()  # type: ignore
+            if not m:
+                # Bad nodes should have been detected earlier; fail loudly
+                raise ValueError(  # pragma: no cover
+                    f"Unexpected graph expression: '{right}'"
+                )
+            suicide_char, name, offset, output, opt_char = m.groups()
             suicide = (suicide_char == self.__class__.SUICIDE)
             optional = (opt_char == self.__class__.OPTIONAL)
             if output:
@@ -857,36 +960,52 @@ class GraphParser:
 
             if name in self.family_map:
                 fam = True
-                mems = self.family_map[name]
-                if not output:
-                    # (Plain family name on RHS).
-                    # Make implicit success explicit.
+                rhs_members = self.family_map[name]
+                if not output and not expr:
+                    # Infer :succeed-all for lone family nodes, e.g. for
+                    # "R1 = FAM": members default to success required, or
+                    # for "FAM:succeed-all?" they default to success optional.
                     output = QUAL_FAM_SUCCEED_ALL
-                elif output.startswith("finish"):
+                elif output and output.startswith("finish"):
                     if optional:
                         raise GraphParseError(
                             f"Family pseudo-output {name}:{output} can't be"
                             " optional")
-                    # But implicit optional for the real succeed/fail outputs.
-                    optional = True
-                try:
-                    outputs = self.__class__.fam_to_mem_output_map[output]
-                except KeyError:
-                    # Illegal family trigger on RHS of a pair.
-                    raise GraphParseError(
-                        f"Illegal family trigger: {name}:{output}")
+                    else:
+                        # Implicit optional for the real succeed/fail outputs.
+                        optional = True
+                if output:
+                    try:
+                        outputs = self.__class__.fam_to_mem_output_map[output]
+                    except KeyError:
+                        # Illegal family trigger on RHS of a pair.
+                        raise GraphParseError(
+                            f"Illegal family trigger: {name}:{output}"
+                        ) from None
+                else:
+                    outputs = ['']
             else:
                 fam = False
-                if not output:
-                    # Make implicit success explicit.
-                    output = TASK_OUTPUT_SUCCEEDED
-                else:
+                rhs_members = [name]
+                if output:
                     # Convert to standard output names if necessary.
                     output = TaskTrigger.standardise_name(output)
-                mems = [name]
-                outputs = [output]
+                elif optional or (
+                    right not in self.end_of_chain_nodes
+                    or not expr
+                ):
+                    # Infer "name:succeeded?" for explicit "name?"
+                    # Infer "name:succeeded" for plain "name"
+                    #   if not (end-of-chain and left is not None)
+                    output = TASK_OUTPUT_SUCCEEDED
+                outputs = [output]  # may be [None]
 
-            for mem in mems:
-                self._set_triggers(mem, suicide, trigs, expr, orig_expr)
+            for mem in rhs_members:
+                if not offset:
+                    # Nodes with offsets on the RHS do not define triggers.
+                    self._set_triggers(mem, suicide, trigs, expr, orig_expr)
                 for output in outputs:
-                    self._set_output_opt(mem, output, optional, suicide, fam)
+                    if output:
+                        # Infer optionality for explicit outputs on RHS.
+                        self._set_output_opt(
+                            mem, output, optional, suicide, fam)
