@@ -22,17 +22,26 @@ This module contains the abstract ID tokenising/detokenising code.
 from enum import Enum
 import re
 from typing import (
+    TYPE_CHECKING,
+    Any,
     Iterable,
     List,
+    Literal,
     Optional,
     Set,
     Tuple,
     Union,
+    cast,
+    overload,
 )
 
 from cylc.flow import LOG
 
 
+if TYPE_CHECKING:
+    from cylc.flow.cycling import PointBase
+
+
 class IDTokens(Enum):
     """Cylc object identifier tokens."""
 
@@ -74,7 +83,7 @@ class Tokens(dict):
         <id: w//c>
         >>> Tokens(workflow='w', cycle='c')['job']
 
-        # Make a copy (note Tokens are mutable):
+        # Make a copy (note Tokens are immutable):
         >>> tokens.duplicate()
         <id: ~u/w//c/t/01>
         >>> tokens.duplicate(job='02')  # make changes at the same time
@@ -118,16 +127,17 @@ class Tokens(dict):
         dict.__init__(self, **kwargs)
 
     def __setitem__(self, key, value):
-        if key not in self._KEYS:
-            raise ValueError(f'Invalid token: {key}')
-        dict.__setitem__(self, key, value)
+        raise Exception('Tokens objects are not mutable')
+
+    def update(self, other):
+        raise Exception('Tokens objects are not mutable')
 
     def __getitem__(self, key):
         try:
             return dict.__getitem__(self, key)
         except KeyError:
             if key not in self._KEYS:
-                raise ValueError(f'Invalid token: {key}')
+                raise ValueError(f'Invalid token: {key}') from None
             return None
 
     def __str__(self):
@@ -151,16 +161,26 @@ class Tokens(dict):
             id_ = self.id
         return f'<id: {id_}>'
 
+    def __hash__(self):
+        # generate the __hash__ from the non None items in the dictionary
+        return hash(tuple(sorted(((k, v) for k, v in self.items() if v))))
+
     def __eq__(self, other):
-        if not isinstance(other, self.__class__):
+        if not isinstance(other, Tokens):
             return False
         return all(
             self[key] == other[key]
             for key in self._KEYS
         )
 
+    def __lt__(self, other):
+        return self.id < other.id
+
+    def __gt__(self, other):
+        return self.id > other.id
+
     def __ne__(self, other):
-        if not isinstance(other, self.__class__):
+        if not isinstance(other, Tokens):
             return True
         return any(
             self[key] != other[key]
@@ -266,7 +286,7 @@ class Tokens(dict):
             <id: >
             >>> tokens.pop_token()
             Traceback (most recent call last):
-            KeyError: No defined tokens.
+            KeyError: 'No defined tokens.'
 
         """
         for token in reversed(IDTokens):
@@ -336,11 +356,9 @@ class Tokens(dict):
             >>> tokens = Tokens()
             >>> tokens.is_null
             True
-            >>> tokens['job_sel'] = 'x'
-            >>> tokens.is_null
+            >>> tokens.duplicate(job_sel='x').is_null
             True
-            >>> tokens['job'] = '01'
-            >>> tokens.is_null
+            >>> tokens.duplicate(job='01').is_null
             False
 
         """
@@ -348,50 +366,40 @@ class Tokens(dict):
             self[key] for key in self._REGULAR_KEYS
         )
 
-    def update_tokens(
-        self,
-        tokens: 'Optional[Tokens]' = None,
-        **kwargs
-    ) -> None:
-        """Update the tokens dictionary.
-
-        Similar to dict.update but with an optional Tokens argument.
+    @property
+    def submit_num(self) -> int | None:
+        """The job submit number as an integer, or None if not set.
 
         Examples:
-            >>> tokens = Tokens('x')
-            >>> tokens.update_tokens(workflow='y')
-            >>> tokens
-            <id: y>
-            >>> tokens.update_tokens(Tokens('z'))
-            >>> tokens
-            <id: z>
-            >>> tokens.update_tokens(Tokens('a'), cycle='b')
-            >>> tokens
-            <id: a//b>
-
+            >>> Tokens('//c/t/01').submit_num
+            1
+            >>> Tokens('//c/t').submit_num is None
+            True
         """
-        if tokens:
-            for key, value in tokens.items():
-                self[key] = value
-        for key, value in kwargs.items():
-            self[key] = value
+        return int(self['job']) if self['job'] else None
 
-    def update(self, other):
-        """dict.update.
+    @overload
+    def duplicate(
+        self,
+        *,
+        cycle: str,
+        task: str,
+        **kwargs,
+    ) -> 'TaskTokens':
+        ...
 
-        Example:
-            >>> tokens = Tokens(workflow='w')
-            >>> tokens.update({'cycle': 'c'})
-            >>> tokens.id
-            'w//c'
-
-        """
-        return self.update_tokens(**other)
+    @overload
+    def duplicate(
+        self,
+        *tokens_list: 'Tokens',
+        **kwargs,
+    ) -> 'Tokens':
+        ...
 
     def duplicate(
         self,
-        tokens: 'Optional[Tokens]' = None,
-        **kwargs
+        *tokens_list: 'Tokens',
+        **kwargs,
     ) -> 'Tokens':
         """Duplicate a tokens object.
 
@@ -408,23 +416,65 @@ class Tokens(dict):
             >>> id(tokens1) == id(tokens2)
             False
 
-            Make a copy and modify it:
+            Make a copy with a modification:
             >>> tokens1.duplicate(cycle='1').id
             '~u/w//1'
 
-            Original not changed
+            The Original is not changed:
             >>> tokens1.id
             '~u/w'
+
+            Arguments override in definition order:
+            >>> Tokens.duplicate(
+            ...     tokens1,
+            ...     Tokens(cycle='c', task='a', job='01'),
+            ...     task='b'
+            ... ).id
+            '~u/w//c/b/01'
+
         """
-        ret = Tokens(self)
-        ret.update_tokens(tokens, **kwargs)
-        return ret
+        _kwargs: dict[str, Any] = {}
+        for tokens in (self, *tokens_list):
+            _kwargs.update(tokens)
+        _kwargs.update(kwargs)
+        return Tokens(**_kwargs)
+
+
+class TaskTokens(Tokens):
+    """A Tokens object where the cycle and task are compulsory."""
+
+    def __init__(self, cycle: str, task: str, **kwargs):
+        Tokens.__init__(self, cycle=cycle, task=task, **kwargs)
+
+    @overload
+    def __getitem__(self, key: "Literal['cycle']") -> str:
+        ...
+
+    @overload
+    def __getitem__(self, key: "Literal['task']") -> str:
+        ...
+
+    def __getitem__(self, key: str) -> Optional[str]:
+        return Tokens.__getitem__(self, key)
+
+    def duplicate(self, *tokens_list, **kwargs) -> 'TaskTokens':
+        return cast(
+            'TaskTokens', Tokens.duplicate(self, *tokens_list, **kwargs)
+        )
+
+    @property
+    def task(self) -> 'TaskTokens':
+        return cast('TaskTokens', Tokens.task.fget(self))  # type: ignore
+
+    @property
+    def is_task_like(self) -> 'Literal[True]':
+        return True
 
 
 # //cycle[:sel][/task[:sel][/job[:sel]]]
 RELATIVE_PATTERN = rf'''
     //
-    (?P<{IDTokens.Cycle.value}>[^~\/:\n]+)
+    (?P<{IDTokens.Cycle.value}>[^~\/:\n][^~\/\n]*?)
     (?:
       :
       (?P<{IDTokens.Cycle.value}_sel>[^\/:\n]+)
@@ -497,7 +547,7 @@ UNIVERSAL_ID = re.compile(
             )?
             (?:
                 # cycle/task/job
-                { RELATIVE_PATTERN }
+                {RELATIVE_PATTERN}
             )?
           )?
         )?
@@ -545,19 +595,38 @@ LEGACY_CYCLE_SLASH_TASK = re.compile(
 )
 
 
-def quick_relative_detokenise(cycle, task):
-    """Generate a relative ID for a task.
+def quick_relative_id(
+    cycle: Union[str, int, 'PointBase'],
+    task: str,
+    task_sel: Optional[str] = None
+) -> str:
+    """Generate a relative ID for a task, with optional selector.
 
     This is a more efficient solution to `Tokens` for cases where
     you only want the ID string and don't have any use for a Tokens object.
 
     Example:
-        >>> q = quick_relative_detokenise
+        >>> q = quick_relative_id
         >>> q('1', 'a') == Tokens(cycle='1', task='a').relative_id
         True
 
+        >>> q('1', 'a', 'succeeded')
+        '1/a:succeeded'
+
+        >>> q('1', 'a', 'succeeded') == (
+        ...     detokenise(
+        ...         Tokens(cycle='1', task='a', task_sel="succeeded"),
+        ...         selectors=True,
+        ...         relative=True
+        ...     )
+        ... )
+        True
+
     """
-    return f'{cycle}/{task}'
+    if task_sel is None:
+        return f'{cycle}/{task}'
+    else:
+        return f'{cycle}/{task}:{task_sel}'
 
 
 def _dict_strip(dictionary):
