@@ -20,6 +20,9 @@ from pathlib import Path
 import re
 from typing import Optional, Dict, List, Tuple, Any
 
+from metomi.isodatetime.parsers import TimePointParser
+from metomi.isodatetime.exceptions import ISO8601SyntaxError
+
 from cylc.flow import LOG
 from cylc.flow.exceptions import (
     InputError,
@@ -28,14 +31,10 @@ from cylc.flow.hostuserutil import get_user
 from cylc.flow.id import (
     Tokens,
     contains_multiple_workflows,
+    tokenise,
     upgrade_legacy_ids,
 )
 from cylc.flow.pathutil import EXPLICIT_RELATIVE_PATH_REGEX
-from cylc.flow.network.scan import (
-    filter_name,
-    is_active,
-    scan,
-)
 from cylc.flow.workflow_files import (
     check_flow_file,
     detect_both_flow_and_suite,
@@ -48,6 +47,36 @@ from cylc.flow.workflow_files import (
 
 
 FN_CHARS = re.compile(r'[\*\?\[\]\!]')
+TP_PARSER = TimePointParser()
+
+
+def cli_tokenise(id_: str) -> Tokens:
+    """Tokenise with support for long-format datetimes.
+
+    If a cycle selector is present, it could be part of a long-format
+    ISO 8601 datetime that was erroneously split. Re-attach it if it
+    results in a valid datetime.
+
+    Examples:
+        >>> f = lambda t: {k: v for k, v in t.items() if v is not None}
+        >>> f(cli_tokenise('foo//2021-01-01T00:00Z'))
+        {'workflow': 'foo', 'cycle': '2021-01-01T00:00Z'}
+        >>> f(cli_tokenise('foo//2021-01-01T00:horse'))
+        {'workflow': 'foo', 'cycle': '2021-01-01T00', 'cycle_sel': 'horse'}
+    """
+    tokens = tokenise(id_)
+    cycle = tokens['cycle']
+    cycle_sel = tokens['cycle_sel']
+    if not (cycle and cycle_sel) or '-' not in cycle:
+        return tokens
+    cycle = f'{cycle}:{cycle_sel}'
+    try:
+        TP_PARSER.parse(cycle)
+    except ISO8601SyntaxError:
+        return tokens
+    dict.__setitem__(tokens, 'cycle', cycle)
+    del tokens['cycle_sel']
+    return tokens
 
 
 def _parse_cli(*ids: str) -> List[Tokens]:
@@ -104,17 +133,21 @@ def _parse_cli(*ids: str) -> List[Tokens]:
         # errors:
         >>> _parse_cli('////')
         Traceback (most recent call last):
-        InputError: Invalid ID: ////
+        cylc.flow.exceptions.InputError: Invalid ID: ////
 
         >>> parse_back('//cycle')
         Traceback (most recent call last):
-        InputError: Relative reference must follow an incomplete one.
-        E.G: workflow //cycle/task
+        cylc.flow.exceptions.InputError: Relative reference must follow an
+        incomplete one...
 
         >>> parse_back('workflow//cycle', '//cycle')
         Traceback (most recent call last):
-        InputError: Relative reference must follow an incomplete one.
-        E.G: workflow //cycle/task
+        cylc.flow.exceptions.InputError: Relative reference must follow an
+        incomplete one...
+
+        >>> parse_back('workflow///cycle/')
+        Traceback (most recent call last):
+        cylc.flow.exceptions.InputError: Invalid ID: workflow///cycle/
 
     """
     # upgrade legacy ids if required
@@ -125,14 +158,18 @@ def _parse_cli(*ids: str) -> List[Tokens]:
     tokens_list: List[Tokens] = []
     for id_ in ids:
         try:
-            tokens = Tokens(id_)
+            tokens = cli_tokenise(id_)
         except ValueError:
             if id_.endswith('/') and not id_.endswith('//'):  # noqa: SIM106
                 # tolerate IDs that end in a single slash on the CLI
                 # (e.g. CLI auto completion)
-                tokens = Tokens(id_[:-1])
+                try:
+                    # this ID is invalid with or without the trailing slash
+                    tokens = cli_tokenise(id_[:-1])
+                except ValueError:
+                    raise InputError(f'Invalid ID: {id_}') from None
             else:
-                raise InputError(f'Invalid ID: {id_}')
+                raise InputError(f'Invalid ID: {id_}') from None
         is_partial = tokens.get('workflow') and not tokens.get('cycle')
         is_relative = not tokens.get('workflow')
 
@@ -197,6 +234,7 @@ async def parse_ids_async(
     constraint: str = 'tasks',
     max_workflows: Optional[int] = None,
     max_tasks: Optional[int] = None,
+    alt_run_dir: Optional[str] = None,
 ) -> Tuple[Dict[str, List[Tokens]], Any]:
     """Parse IDs from the command line.
 
@@ -231,6 +269,8 @@ async def parse_ids_async(
         max_tasks:
             Specify the maximum number of tasks permitted to be specified
             in the ids.
+        alt_run_dir:
+            Specify a non-standard cylc-run location, e.g. for another user.
 
     Returns:
         With src=True":
@@ -293,7 +333,8 @@ async def parse_ids_async(
 
     # infer the run number if not specified the ID (and if possible)
     if infer_latest_runs:
-        _infer_latest_runs(*tokens_list, src_path=src_path)
+        _infer_latest_runs(
+            tokens_list, src_path=src_path, alt_run_dir=alt_run_dir)
 
     _validate_number(
         *tokens_list,
@@ -306,7 +347,7 @@ async def parse_ids_async(
     if src:
         if not flow_file_path:
             # get the workflow file path from the run dir
-            flow_file_path = get_flow_file(list(workflows)[0])
+            flow_file_path = get_flow_file(next(iter(workflows)))
         return workflows, flow_file_path
     return workflows, multi_mode
 
@@ -334,7 +375,7 @@ async def parse_id_async(
             'max_tasks': 1,
         },
     )
-    workflow_id = list(workflows)[0]
+    workflow_id = next(iter(workflows))
     tokens_list = workflows[workflow_id]
     tokens: Optional[Tokens]
     if tokens_list:
@@ -408,26 +449,30 @@ def _validate_workflow_ids(*tokens_list, src_path):
         detect_both_flow_and_suite(src_path)
 
 
-def _infer_latest_runs(*tokens_list, src_path):
+def _infer_latest_runs(tokens_list, src_path, alt_run_dir=None):
     for ind, tokens in enumerate(tokens_list):
         if ind == 0 and src_path:
             # source workflow passed in as a path
             continue
-        tokens['workflow'] = infer_latest_run_from_id(tokens['workflow'])
+        tokens_list[ind] = tokens.duplicate(
+            workflow=infer_latest_run_from_id(
+                tokens['workflow'], alt_run_dir
+            )
+        )
         pass
 
 
 def _validate_number(*tokens_list, max_workflows=None, max_tasks=None):
     if not max_workflows and not max_tasks:
         return
-    workflows_count = 0
+    workflows_seen = set()
     tasks_count = 0
     for tokens in tokens_list:
         if tokens.is_task_like:
             tasks_count += 1
-        else:
-            workflows_count += 1
-    if max_workflows and workflows_count > max_workflows:
+        if tokens["workflow"] is not None:
+            workflows_seen.add(tokens["workflow"])
+    if max_workflows and len(workflows_seen) > max_workflows:
         raise InputError(
             f'IDs contain too many workflows (max {max_workflows})'
         )
@@ -487,6 +532,12 @@ async def _expand_workflow_tokens_impl(tokens, match_active=True):
             'currently supported.'
         )
 
+    # import only when needed to avoid slowing CLI unnecessarily
+    from cylc.flow.network.scan import (
+        filter_name,
+        is_active,
+        scan,
+    )
     # construct the pipe
     pipe = scan | filter_name(fnmatch.translate(tokens['workflow']))
     if match_active is not None:
