@@ -16,9 +16,14 @@
 """Package for network interfaces to Cylc scheduler objects."""
 
 import asyncio
-import getpass
 import json
-from typing import Optional, Tuple
+from typing import (
+    TYPE_CHECKING,
+    Optional,
+    Tuple,
+    TypedDict,
+    Union,
+)
 
 import zmq
 import zmq.asyncio
@@ -30,38 +35,78 @@ from cylc.flow.exceptions import (
     CylcError,
     CylcVersionError,
     ServiceFileError,
-    WorkflowStopped
+    WorkflowStopped,
 )
 from cylc.flow.hostuserutil import get_fqdn_by_host
 from cylc.flow.workflow_files import (
     ContactFileFields,
-    KeyType,
-    KeyOwner,
     KeyInfo,
+    KeyOwner,
+    KeyType,
+    get_workflow_srv_dir,
     load_contact_file,
-    get_workflow_srv_dir
 )
 
+
+if TYPE_CHECKING:
+    from zmq.asyncio import Context
+
+
 API = 5  # cylc API version
 MSG_TIMEOUT = "TIMEOUT"
 
+if TYPE_CHECKING:
+    class ResponseDict(TypedDict, total=False):
+        """Structure of server response messages.
 
-def encode_(message):
-    """Convert the structure holding a message field from JSON to a string."""
-    try:
-        return json.dumps(message)
-    except TypeError as exc:
-        return json.dumps({'errors': [{'message': str(exc)}]})
+        Confusingly, has similar format to GraphQL execution result.
+        But if we change this now we could break compatibility for
+        issuing commands to/receiving responses from workflows running in
+        different versions of Cylc 8.
+        """
+        data: object
+        """For most Cylc commands that issue GraphQL mutations, the data field
+        will look like:
+        data: {
+        <mutationName1>: {
+            result: [
+            {
+                id: <workflow/task ID>,
+                response: [<success_bool>, <message>]
+            },
+            ...
+            ]
+        }
+        }
+        but this is not 100% consistent unfortunately
+        """
+        error: Union[Exception, str, dict]
+        """If an error occurred that could not be handled.
+        (usually a dict {message: str, traceback?: str}).
+        """
+        user: str
+        cylc_version: str
+        """Server (i.e. running workflow) Cylc version.
+
+        Going forward, we include this so we can more easily handle any future
+        back-compat issues."""
 
 
-def decode_(message):
-    """Convert an encoded message string to JSON with an added 'user' field."""
-    msg = json.loads(message)
-    msg['user'] = getpass.getuser()  # assume this is the user
-    return msg
+def serialize(data: object) -> str:
+    """Convert the structure holding a message to a JSON message string."""
+    # Abstract out the transport format in order to allow it to be changed
+    # in future.
+    return json.dumps(data)
 
 
-def get_location(workflow: str) -> Tuple[str, int, int]:
+def deserialize(message: str) -> 'ResponseDict':
+    """Convert a JSON message string to dict with an added 'user' field."""
+    # Abstract out the transport format in order to allow it to be changed
+    # in future.
+    return json.loads(message)
+
+
+def get_location(workflow: str) -> Tuple[str, int, int, str]:
     """Extract host and port from a workflow's contact file.
 
     NB: if it fails to load the workflow contact file, it will exit.
@@ -69,7 +114,7 @@ def get_location(workflow: str) -> Tuple[str, int, int]:
     Args:
         workflow: workflow ID
     Returns:
-        Tuple (host name, port number, publish port number)
+        Tuple (host name, port number, publish port number, scheduler version)
     Raises:
         WorkflowStopped: if the workflow is not running.
         CylcVersionError: if target is a Cylc 7 (or earlier) workflow.
@@ -78,17 +123,17 @@ def get_location(workflow: str) -> Tuple[str, int, int]:
         contact = load_contact_file(workflow)
     except (IOError, ValueError, ServiceFileError):
         # Contact file does not exist or corrupted, workflow should be dead
-        raise WorkflowStopped(workflow)
+        raise WorkflowStopped(workflow) from None
 
     host = contact[ContactFileFields.HOST]
     host = get_fqdn_by_host(host)
     port = int(contact[ContactFileFields.PORT])
+    version = contact[ContactFileFields.VERSION]
     if ContactFileFields.PUBLISH_PORT in contact:
         pub_port = int(contact[ContactFileFields.PUBLISH_PORT])
     else:
-        version = contact.get('CYLC_VERSION', None)
         raise CylcVersionError(version=version)
-    return host, port, pub_port
+    return host, port, pub_port, version
 
 
 class ZMQSocketBase:
@@ -115,11 +160,11 @@ class ZMQSocketBase:
         pattern,
         workflow: str,
         bind: bool = False,
-        context: Optional[zmq.Context] = None,
+        context: 'Optional[Context]' = None,
     ):
         self.bind = bind
         if context is None:
-            self.context: zmq.Context = zmq.asyncio.Context()
+            self.context: 'Context' = zmq.asyncio.Context()
         else:
             self.context = context
         self.pattern = pattern
@@ -176,16 +221,14 @@ class ZMQSocketBase:
                 srv_prv_key_info.full_key_path)
         except ValueError:
             raise ServiceFileError(
-                f"Failed to find server's public "
-                f"key in "
+                "Failed to find server's public key in "
                 f"{srv_prv_key_info.full_key_path}."
-            )
-        except OSError:
+            ) from None
+        except OSError as exc:
             raise ServiceFileError(
-                f"IO error opening server's private "
-                f"key from "
+                "IO error opening server's private key from "
                 f"{srv_prv_key_info.full_key_path}."
-            )
+            ) from exc
         if server_private_key is None:  # this can't be caught by exception
             raise ServiceFileError(
                 f"Failed to find server's private "
@@ -204,7 +247,9 @@ class ZMQSocketBase:
                 self.port = self.socket.bind_to_random_port(
                     'tcp://*', min_port, max_port)
         except (zmq.error.ZMQError, zmq.error.ZMQBindError) as exc:
-            raise CylcError(f'could not start Cylc ZMQ server: {exc}')
+            raise CylcError(
+                f'could not start Cylc ZMQ server: {exc}'
+            ) from None
 
     # Keeping srv_public_key_loc as optional arg so as to not break interface
     def _socket_connect(self, host, port, srv_public_key_loc=None):
@@ -236,8 +281,10 @@ class ZMQSocketBase:
         try:
             client_public_key, client_priv_key = zmq.auth.load_certificate(
                 client_priv_key_info.full_key_path)
-        except (OSError, ValueError):
-            raise ClientError(error_msg)
+        except ValueError:
+            raise ClientError(error_msg) from None
+        except OSError as exc:
+            raise ClientError(error_msg) from exc
         if client_priv_key is None:  # this can't be caught by exception
             raise ClientError(error_msg)
         self.socket.curve_publickey = client_public_key
@@ -245,6 +292,9 @@ class ZMQSocketBase:
 
         # A client can only connect to the server if it knows its public key,
         # so we grab this from the location it was created on the filesystem:
+        error_msg = (
+            "Failed to load the workflow's public key, so cannot connect."
+        )
         try:
             # 'load_certificate' will try to load both public & private keys
             # from a provided file but will return None, not throw an error,
@@ -254,9 +304,10 @@ class ZMQSocketBase:
             server_public_key = zmq.auth.load_certificate(
                 srv_pub_key_info.full_key_path)[0]
             self.socket.curve_serverkey = server_public_key
-        except (OSError, ValueError):  # ValueError raised w/ no public key
-            raise ClientError(
-                "Failed to load the workflow's public key, so cannot connect.")
+        except ValueError:  # ValueError raised w/ no public key
+            raise ClientError(error_msg) from None
+        except OSError as exc:
+            raise ClientError(error_msg) from exc
 
         self.socket.connect(f'tcp://{host}:{port}')
 
