@@ -30,26 +30,30 @@ parsec config file parsing:
       value type is known).
 """
 
+from copy import deepcopy
 import os
-from optparse import Values
 from pathlib import Path
 import re
 import sys
 import typing as t
 
-from cylc.flow import __version__, iter_entry_points
+from cylc.flow import __version__
 from cylc.flow import LOG
-from cylc.flow.exceptions import PluginError
 from cylc.flow.parsec.exceptions import (
     FileParseError, ParsecError, TemplateVarLanguageClash
 )
-from cylc.flow.parsec.OrderedDict import OrderedDictWithDefaults
 from cylc.flow.parsec.include import inline
+from cylc.flow.parsec.OrderedDict import OrderedDictWithDefaults
+from cylc.flow.plugins import run_plugins
 from cylc.flow.parsec.util import itemstr
 from cylc.flow.templatevars import get_template_vars_from_db
 from cylc.flow.workflow_files import (
     get_workflow_source_dir, check_flow_file)
 
+if t.TYPE_CHECKING:
+    from optparse import Values
+    from typing import Union
+
 
 # heading/sections can contain commas (namespace name lists) and any
 # regex pattern characters (this was for pre cylc-6 satellite tasks).
@@ -103,6 +107,34 @@ _TRIPLE_QUOTE = {
 _UNCLOSED_MULTILINE = re.compile(
     r'(?<![\w>])\[.*\]'
 )
+TEMPLATING_DETECTED = 'templating_detected'
+TEMPLATE_VARIABLES = 'template_variables'
+EXTRA_VARS_TEMPLATE: t.Dict[str, t.Any] = {
+    'env': {},
+    TEMPLATE_VARIABLES: {},
+    TEMPLATING_DETECTED: None
+}
+
+
+def get_cylc_env_vars() -> t.Dict[str, str]:
+    """Return a restricted dict of CYLC_ environment variables for templating.
+
+    The following variables are ignored because the do not necessarily reflect
+    the running code version (I might not use the "cylc" wrapper, or it might
+    select a different version):
+
+    CYLC_VERSION
+        Set as a template variable elsewhere, from the hardwired code version.
+
+    CYLC_ENV_NAME
+        Providing it as a template variable would just be misleading.
+    """
+    return {
+        key: val
+        for key, val in os.environ.items()
+        if key.startswith('CYLC_')
+        if key not in ["CYLC_VERSION", "CYLC_ENV_NAME"]
+    }
 
 
 def _concatenate(lines):
@@ -219,53 +251,43 @@ def multiline(flines, value, index, maxline):
     return quot + newvalue + line, index
 
 
-def process_plugins(fpath, opts):
+def process_plugins(fpath: 'Union[str, Path]', opts: 'Values'):
     """Run a Cylc pre-configuration plugin.
 
     Plugins should return a dictionary containing:
         'env': A dictionary of environment variables.
         'template_variables': A dictionary of template variables.
         'templating_detected': Where the plugin identifies a templating
-            language this is specified here. Expected values are ``jinja2``
-            or ``empy``.
+            language this is specified here.
 
     args:
-        fpath: Directory where the plugin will look for a config.
+        fpath: Path to a config file. Plugin will look at the parent
+            directory of this file.
         opts: Command line options to be passed to the plugin.
 
     Returns: Dictionary in the form:
         extra_vars = {
             'env': {},
             'template_variables': {},
-            'templating_detected': None
+            TEMPLATING_DETECTED: None
         }
     """
+    fpath = Path(fpath)
+
     # Set out blank dictionary for return:
-    extra_vars = {
-        'env': {},
-        'template_variables': {},
-        'templating_detected': None
-    }
+    extra_vars = deepcopy(EXTRA_VARS_TEMPLATE)
+
+    # Don't run this on global configs:
+    if fpath.name == 'global.cylc':
+        return extra_vars
 
     # Run entry point pre_configure items, trying to merge values with each.:
-    for entry_point in iter_entry_points(
-        'cylc.pre_configure'
+    for entry_point, plugin_result in run_plugins(
+        'cylc.pre_configure',
+        srcdir=fpath.parent,
+        opts=opts,
     ):
-        try:
-            # If you want it to work on sourcedirs you need to get the options
-            # to here.
-            plugin_result = entry_point.resolve()(
-                srcdir=fpath, opts=opts
-            )
-        except Exception as exc:
-            # NOTE: except Exception (purposefully vague)
-            # this is to separate plugin from core Cylc errors
-            raise PluginError(
-                'cylc.pre_configure',
-                entry_point.name,
-                exc
-            ) from None
-        for section in ['env', 'template_variables']:
+        for section in ['env', TEMPLATE_VARIABLES]:
             if section in plugin_result and plugin_result[section] is not None:
                 # Raise error if multiple plugins try to update the same keys.
                 section_update = plugin_result.get(section, {})
@@ -279,26 +301,20 @@ def process_plugins(fpath, opts):
                     )
                 extra_vars[section].update(section_update)
 
+        templating_detected = plugin_result.get(TEMPLATING_DETECTED, None)
         if (
-            'templating_detected' in plugin_result and
-            plugin_result['templating_detected'] is not None and
-            extra_vars['templating_detected'] is not None and
-            extra_vars['templating_detected'] !=
-                plugin_result['templating_detected']
+            templating_detected is not None
+            and extra_vars[TEMPLATING_DETECTED] is not None
+            and extra_vars[TEMPLATING_DETECTED] != templating_detected
         ):
             # Don't allow subsequent plugins with different templating_detected
             raise ParsecError(
                 "Can't merge templating languages "
-                f"{extra_vars['templating_detected']} and "
-                f"{plugin_result['templating_detected']}"
+                f"{extra_vars[TEMPLATING_DETECTED]} and "
+                f"{templating_detected}"
             )
-        elif (
-            'templating_detected' in plugin_result and
-            plugin_result['templating_detected'] is not None
-        ):
-            extra_vars['templating_detected'] = plugin_result[
-                'templating_detected'
-            ]
+        else:
+            extra_vars[TEMPLATING_DETECTED] = templating_detected
 
     return extra_vars
 
@@ -329,8 +345,8 @@ def merge_template_vars(
         >>> merge_template_vars(a, b)
         {'FOO': 42, 'BAZ': 3.14159, 'BAR': 'Hello World'}
     """
-    if plugin_result['templating_detected'] is not None:
-        plugin_tvars = plugin_result['template_variables']
+    if plugin_result[TEMPLATING_DETECTED] is not None:
+        plugin_tvars = plugin_result[TEMPLATE_VARIABLES]
         will_be_overwritten = (
             native_tvars.keys() &
             plugin_tvars.keys()
@@ -429,18 +445,15 @@ def read_and_proc(
         flines = [line.rstrip('\n') for line in f]
 
     do_inline = True
-    do_empy = True
     do_jinja2 = True
     do_contin = True
 
-    extra_vars = process_plugins(Path(fpath).parent, opts)
+    extra_vars = process_plugins(fpath, opts)
 
     if not template_vars:
         template_vars = {}
 
     if viewcfg:
-        if not viewcfg['empy']:
-            do_empy = False
         if not viewcfg['jinja2']:
             do_jinja2 = False
         if not viewcfg['contin']:
@@ -453,43 +466,24 @@ def read_and_proc(
         flines = inline(
             flines, fdir, fpath, viewcfg=viewcfg)
 
+    # Add the hardwired code version to template vars as CYLC_VERSION
     template_vars['CYLC_VERSION'] = __version__
-
     template_vars = merge_template_vars(template_vars, extra_vars)
-
     template_vars['CYLC_TEMPLATE_VARS'] = template_vars
 
+    # Add CYLC_WORKFLOW_SRC_DIR to template variables.
+    sourcepath = get_workflow_source_dir(Path(fpath).parent)[1]
+    template_vars['CYLC_WORKFLOW_SRC_DIR'] = (
+        sourcepath.readlink() if sourcepath else Path(fpath).parent)
+
     # Fail if templating_detected ≠ hashbang
     process_with = hashbang_and_plugin_templating_clash(
-        extra_vars['templating_detected'], flines
+        extra_vars[TEMPLATING_DETECTED], flines
     )
-    # process with EmPy
-    if do_empy:
-        if (
-            extra_vars['templating_detected'] == 'empy' and
-            not process_with and
-            process_with != 'empy'
-        ):
-            flines.insert(0, '#!empy')
-
-        if flines and re.match(r'^#![Ee]m[Pp]y\s*', flines[0]):
-            LOG.debug('Processing with EmPy')
-            try:
-                from cylc.flow.parsec.empysupport import empyprocess
-            except ImportError:
-                raise ParsecError('EmPy Python package must be installed '
-                                  'to process file: ' + fpath)
-            flines = empyprocess(
-                fpath, flines, fdir, template_vars
-            )
 
     # process with Jinja2
     if do_jinja2:
-        if (
-            extra_vars['templating_detected'] == 'jinja2' and
-            not process_with and
-            process_with != 'jinja2'
-        ):
+        if extra_vars[TEMPLATING_DETECTED] == 'jinja2' and not process_with:
             flines.insert(0, '#!jinja2')
 
         if flines and re.match(r'^#![jJ]inja2\s*', flines[0]):
@@ -497,8 +491,10 @@ def read_and_proc(
             try:
                 from cylc.flow.parsec.jinja2support import jinja2process
             except ImportError:
-                raise ParsecError('Jinja2 Python package must be installed '
-                                  'to process file: ' + fpath)
+                raise ParsecError(
+                    'Jinja2 Python package must be installed '
+                    'to process file: ' + fpath
+                ) from None
             flines = jinja2process(
                 fpath, flines, fdir, template_vars
             )
@@ -526,8 +522,7 @@ def hashbang_and_plugin_templating_clash(
         flines: The lines of text from file.
 
     Returns:
-        The hashbang, in lower case, to allow for users using any of
-        ['empy', 'EmPy', 'EMPY'], or similar in other templating languages.
+        The hashbang, in lower case.
 
     Examples:
         - Hashbang and templating_detected match:
@@ -539,7 +534,7 @@ def hashbang_and_plugin_templating_clash(
             >>> thisfunc('', [''])
 
         - Function raises if templating engines clash:
-            >>> thisfunc('empy', ['#!jinja2'])
+            >>> thisfunc('other', ['#!jinja2'])
             Traceback (most recent call last):
                 ...
             cylc.flow.parsec.exceptions.TemplateVarLanguageClash: ...
