@@ -16,23 +16,34 @@
 #
 """Functions relating to (job) platforms."""
 
+from copy import deepcopy
 import random
 import re
-from copy import deepcopy
 from typing import (
-    TYPE_CHECKING, Any, Dict, Iterable,
-    List, Optional, Set, Union, overload
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Set,
+    Union,
+    overload,
 )
 
 from cylc.flow import LOG
-
-from cylc.flow.exceptions import (
-    GlobalConfigError,
-    PlatformLookupError, CylcError, NoHostsError, NoPlatformsError)
 from cylc.flow.cfgspec.glbl_cfg import glbl_cfg
+from cylc.flow.exceptions import (
+    CylcError,
+    GlobalConfigError,
+    NoHostsError,
+    NoPlatformsError,
+    PlatformLookupError,
+)
 from cylc.flow.hostuserutil import is_remote_host
 from cylc.flow.run_modes import JOBLESS_MODES
 
+
 if TYPE_CHECKING:
     from cylc.flow.parsec.OrderedDict import OrderedDictWithDefaults
 
@@ -128,7 +139,7 @@ def get_platform(
 
     Returns:
         platform: A platform definition dictionary. Uses either
-            get_platform() or platform_name_from_job_info(), but to the
+            get_platform() or _platform_name_from_job_info(), but to the
             user these look the same. This will be None if the platform
             definition uses a subshell.
 
@@ -169,7 +180,7 @@ def get_platform(
     task_job_section = task_conf['job'] if 'job' in task_conf else {}
     task_remote_section = task_conf['remote'] if 'remote' in task_conf else {}
     return platform_from_name(
-        platform_name_from_job_info(
+        _platform_name_from_job_info(
             glbl_cfg().get(['platforms']),
             task_job_section,
             task_remote_section,
@@ -329,7 +340,7 @@ def get_platform_from_group(
         return HOST_SELECTION_METHODS[method](platform_names)
 
 
-def platform_name_from_job_info(
+def _platform_name_from_job_info(
     platforms: Union[dict, 'OrderedDictWithDefaults'],
     job: Dict[str, Any],
     remote: Dict[str, Any],
@@ -407,14 +418,14 @@ def platform_name_from_job_info(
         ... }
         >>> job = {'batch system': 'slurm'}
         >>> remote = {'host': 'localhost'}
-        >>> platform_name_from_job_info(platforms, job, remote)
+        >>> _platform_name_from_job_info(platforms, job, remote)
         'sugar'
         >>> remote = {}
-        >>> platform_name_from_job_info(platforms, job, remote)
+        >>> _platform_name_from_job_info(platforms, job, remote)
         'sugar'
         >>> remote ={'host': 'desktop92'}
         >>> job = {}
-        >>> platform_name_from_job_info(platforms, job, remote)
+        >>> _platform_name_from_job_info(platforms, job, remote)
         'desktop92'
     """
 
@@ -581,9 +592,9 @@ def fail_if_platform_and_host_conflict(
     if 'platform' in task_conf and task_conf['platform']:
         fail_items = [
             f'\n * [{section}]{key}'
-            for section, keys in FORBIDDEN_WITH_PLATFORM.items()
+            for section, settings in FORBIDDEN_WITH_PLATFORM.items()
             if section in task_conf
-            for key, _ in keys.items()
+            for key in settings.keys()
             if (
                 key in task_conf[section] and
                 task_conf[section][key] is not None
@@ -647,14 +658,14 @@ def get_install_target_from_platform(platform: Dict[str, Any]) -> str:
 
 def get_install_target_to_platforms_map(
     platform_names: Iterable[str],
-    quiet: bool = False
-) -> Dict[str, List[Dict[str, Any]]]:
+) -> dict[str, list[dict[str, Any]]]:
     """Get a dictionary of unique install targets and the platforms which use
     them.
 
+    Ignores PlatformLookupErrors.
+
     Args:
         platform_names: List of platform names to look up in the global config.
-        quiet: Supress PlatformLookupErrors
 
     Return {install_target_1: [platform_1_dict, platform_2_dict, ...], ...}
     """
@@ -662,12 +673,10 @@ def get_install_target_to_platforms_map(
     for p_name in set(platform_names):
         try:
             platform = platform_from_name(p_name)
-        except PlatformLookupError as exc:
-            if not quiet:
-                raise exc
-        else:
-            install_target = get_install_target_from_platform(platform)
-            ret.setdefault(install_target, []).append(platform)
+        except PlatformLookupError:
+            continue
+        install_target = get_install_target_from_platform(platform)
+        ret.setdefault(install_target, []).append(platform)
 
     return ret
 
