@@ -80,8 +80,10 @@ Broadcast cannot change [runtime] inheritance.
 """
 
 from ansimarkup import parse as cparse
+import asyncio
 from copy import deepcopy
 from functools import partial
+import os.path
 import re
 import sys
 from tempfile import NamedTemporaryFile
@@ -94,7 +96,7 @@ from cylc.flow.broadcast_report import (
 from cylc.flow.cfgspec.workflow import SPEC, upg
 from cylc.flow.exceptions import InputError
 from cylc.flow.network.client_factory import get_client
-from cylc.flow.network.multi import call_multi
+from cylc.flow.network.multi import call_multi_async
 from cylc.flow.option_parsers import (
     WORKFLOW_ID_MULTI_ARG_DOC,
     CylcOptionParser as COP,
@@ -109,6 +111,11 @@ if TYPE_CHECKING:
     from optparse import Values
 
 
+RAW_DEPR_MSG = (
+    "DEPRECATED: the --raw option will be removed at Cylc 8.7; "
+    "use --format=raw instead."
+)
+
 REC_ITEM = re.compile(r'^\[([^\]]*)\](.*)$')
 
 MUTATION = '''
@@ -160,7 +167,7 @@ def get_padding(settings, level=0, padding=0):
     return padding
 
 
-def get_rdict(left, right=None):
+def get_rdict(left, right=None, for_cancel_broadcast=False):
     """Check+transform left=right into a nested dict.
 
     left can be key, [key], [key1]key2, [key1][key2], [key1][key2]key3, etc.
@@ -186,7 +193,11 @@ def get_rdict(left, right=None):
             # item = right
             cur_dict[tail.strip()] = right
             tail = None
-    upg({'runtime': {'__MANY__': rdict}}, 'test')
+    upg(
+        {'runtime': {'__MANY__': rdict}},
+        'test',
+        for_cancel_broadcast=for_cancel_broadcast,
+    )
     # Perform validation, but don't coerce the original (deepcopy).
     cylc_config_validate(deepcopy(rdict), SPEC['runtime']['__MANY__'])
     return rdict
@@ -203,7 +214,7 @@ def files_to_settings(settings, setting_files, cancel_mode=False):
                 handle.seek(0, 0)
                 cfg.loadcfg(handle.name)
         else:
-            cfg.loadcfg(setting_file)
+            cfg.loadcfg(os.path.abspath(setting_file))
     stack = [([], cfg.get(sparse=True))]
     while stack:
         keys, item = stack.pop()
@@ -310,12 +321,33 @@ def get_option_parser() -> COP:
         help="Use unicode box characters with -d, -k.",
         action="store_true", default=False, dest="unicode")
 
+    # BACK COMPAT: --raw
+    # From: < 8.5.1
+    # To: 8.5.1
+    # Remove at: 8.7.0
     parser.add_option(
         "-r", "--raw",
-        help="With -d/--display or -k/--display-task, write out "
-             "the broadcast config structure in raw Python form.",
+        help=(
+            "With -d/--display or -k/--display-task, write out "
+            "the broadcast config structure in raw Python form. "
+            f"{RAW_DEPR_MSG}"
+        ),
         action="store_true", default=False, dest="raw")
 
+    parser.add_option(
+        '--format',
+        help=(
+            "With -d/--display or -k/--display-task, write out "
+            "the broadcast config structure in one of the following formats: "
+            "tree, json, or raw (like json but as a Python dictionary). "
+            r"Default: %default."
+        ),
+        action='store',
+        dest='format',
+        choices=('tree', 'json', 'raw'),
+        default='tree',
+    )
+
     return parser
 
 
@@ -323,6 +355,10 @@ async def run(options: 'Values', workflow_id):
     """Implement cylc broadcast."""
     pclient = get_client(workflow_id, timeout=options.comms_timeout)
 
+    # remove any duplicate namespaces
+    # see https://github.com/cylc/cylc-flow/issues/6334
+    namespaces = list(set(options.namespaces))
+
     ret: Dict[str, Any] = {
         'stdout': [],
         'stderr': [],
@@ -335,7 +371,7 @@ async def run(options: 'Values', workflow_id):
             'wFlows': [workflow_id],
             'bMode': 'Set',
             'cPoints': options.point_strings,
-            'nSpaces': options.namespaces,
+            'nSpaces': namespaces,
             'bSettings': options.settings,
             'bCutoff': options.expire,
         }
@@ -350,6 +386,9 @@ async def run(options: 'Values', workflow_id):
 
     }
 
+    if options.raw:
+        ret['stderr'].append(cparse(f"<yellow>{RAW_DEPR_MSG}</yellow>"))
+
     if options.show or options.showtask:
         if options.showtask:
             try:
@@ -358,12 +397,17 @@ async def run(options: 'Values', workflow_id):
                 # TODO validate showtask?
                 raise InputError(
                     'TASK_ID_GLOB must be in the format: cycle/task'
-                )
+                ) from None
         result = await pclient.async_request('graphql', query_kwargs)
         for wflow in result['workflows']:
             settings = wflow['broadcasts']
             padding = get_padding(settings) * ' '
-            if options.raw:
+            if options.format == 'json':
+                import json
+                ret['stdout'].append(
+                    json.dumps(settings, indent=2, sort_keys=True)
+                )
+            elif options.raw or options.format == 'raw':
                 ret['stdout'].append(str(settings))
             else:
                 ret['stdout'].extend(
@@ -380,7 +424,6 @@ async def run(options: 'Values', workflow_id):
         mutation_kwargs['variables']['bMode'] = 'Expire'
 
     # implement namespace and cycle point defaults here
-    namespaces = options.namespaces
     if not namespaces:
         namespaces = ["root"]
     point_strings = options.point_strings
@@ -394,7 +437,7 @@ async def run(options: 'Values', workflow_id):
                 raise InputError(
                     "--cancel=[SEC]ITEM does not take a value")
             option_item = option_item.strip()
-            setting = get_rdict(option_item)
+            setting = get_rdict(option_item, for_cancel_broadcast=True)
             settings.append(setting)
         files_to_settings(settings, options.cancel_files, options.cancel)
         mutation_kwargs['variables'].update(
@@ -450,25 +493,24 @@ async def run(options: 'Values', workflow_id):
     return ret
 
 
-def report(ret):
-    for line in ret['stdout']:
-        print(line)
-    for line in ret['stderr']:
-        if line is not None:
-            print(line, file=sys.stderr)
+def report(response):
+    return (
+        '\n'.join(response['stdout']),
+        '\n'.join(line for line in response['stderr'] if line is not None),
+        response['exit'] == 0,
+    )
 
 
 @cli_function(get_option_parser)
 def main(_, options: 'Values', *ids) -> None:
-    rets = call_multi(
+    rets = asyncio.run(_main(options, *ids))
+    sys.exit(all(rets.values()) is False)
+
+
+async def _main(options: 'Values', *ids):
+    return await call_multi_async(
         partial(run, options),
         *ids,
         constraint='workflows',
         report=report,
     )
-    if all(
-        ret['exit'] == 0
-        for ret in rets
-    ):
-        sys.exit(0)
-    sys.exit(1)
