@@ -16,16 +16,54 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """cylc main entry point"""
 
-import argparse
-from contextlib import contextmanager
 import os
 import sys
-from typing import Iterator, NoReturn, Optional, Tuple
+
+
+def pythonpath_manip():
+    """Stop PYTHONPATH contaminating the Cylc Environment
+
+    * Remove PYTHONPATH items from sys.path to prevent PYTHONPATH
+      contaminating the Cylc Environment.
+    * Add items from CYLC_PYTHONPATH to sys.path.
+
+    See Also:
+        https://github.com/cylc/cylc-flow/issues/5124
+    """
+    if 'CYLC_PYTHONPATH' in os.environ:
+        paths = [
+            os.path.abspath(item)
+            for item in os.environ['CYLC_PYTHONPATH'].split(os.pathsep)
+        ]
+        paths.extend(sys.path)
+        sys.path = paths
+    if 'PYTHONPATH' in os.environ:
+        for item in os.environ['PYTHONPATH'].split(os.pathsep):
+            abspath = os.path.abspath(item)
+            if abspath in sys.path:
+                sys.path.remove(abspath)
+
+
+pythonpath_manip()
+
+import argparse
+from contextlib import contextmanager
+from importlib.metadata import (
+    entry_points,
+    files,
+)
+from typing import (
+    Iterator,
+    Optional,
+    Tuple,
+)
 
 from ansimarkup import parse as cparse
-import pkg_resources
 
-from cylc.flow import __version__, iter_entry_points
+from cylc.flow import (
+    __version__,
+    iter_entry_points,
+)
 from cylc.flow.option_parsers import (
     format_help_headings,
     format_shell_examples,
@@ -44,7 +82,7 @@ def get_version(long=False):
     from pathlib import Path
     version = f"{__version__}"
     if long:
-        version += f" ({Path(sys.executable).parent.parent})"
+        version += f" ({Path(sys.argv[0])})"
     return version
 
 
@@ -102,8 +140,7 @@ Workflow IDs:
       $ cylc pause foo/run1
       $ cylc stop foo/run1
 
-    In the case of numbered runs (e.g. "run1", "run2", ...) you can omit
-    the run number, Cylc will infer latest run.
+    If you omit run number ("run1", "run2", ...) Cylc will infer latest run.
       $ cylc play foo
       $ cylc pause foo
       $ cylc stop foo
@@ -120,8 +157,7 @@ Workflow IDs:
     You can omit the user name when working on your own workflows.
 
 Cycle / Family / Task / Job IDs:
-    Just as workflows have IDs, the things within workflows have IDs too.
-    These IDs take the format:
+    Just as workflows have IDs, so do objects within workflows:
       cycle/task_or_family/job
 
     Examples:
@@ -130,8 +166,7 @@ Cycle / Family / Task / Job IDs:
       1/a/1  # The first job of the task "a" in the cycle point "1".
 
 Full ID
-    We join the workflow and cycle/task/job IDs together using //:
-      workflow//cycle/task/job
+    Join workflow and cycle/task/job IDs with //: workflow//cycle/task/job
 
     Examples:
       w//         # The workflow "w"
@@ -152,25 +187,28 @@ Patterns
       *                      # All workflows
       test*                  # All workflows starting "test".
       test/*                 # All workflows starting "test/".
-      workflow//*            # All cycles in workflow
+      workflow//*            # All active cycles in workflow
       workflow//cycle/*      # All tasks in workflow//cycle
       workflow//cycle/task/* # All jobs in workflow//cycle/job
 
     Warning:
-      Remember to write IDs inside single quotes when using them on the
-      command line otherwise your shell may expand them.
+      Quote IDs on the command line to protect them from shell expansion.
 
-Filters
-    Filters allow you to filter for specific states.
+Selectors
+    Selectors allow you to filter for specific states.
 
-    Filters are prefixed by a colon (:).
+    Selectors are prefixed by a colon (:).
 
     Examples:
       *:running                       # All running workflows
-      workflow//*:running             # All running cycles in workflow
+      workflow//*:running             # All running tasks in workflow
       workflow//cycle/*:running       # All running tasks in workflow//cycle
       workflow//cycle/task/*:running  # All running jobs in
                                       # workflow//cycle/task
+
+    When selectors are applied to tasks, they will only match active tasks.
+    I.e, "workflow//*:failed" will only select active failed tasks, not all
+    historical failed tasks going back to the start of the workflow.
 '''
 
 
@@ -239,7 +277,8 @@ DEAD_ENDS = {
     'gscan':
         'cylc gscan has been removed, use the web UI',
     'insert':
-        'inserting tasks is now done automatically',
+        'Insertion is no longer required, `cylc set` and `cylc trigger`'
+        ' will insert tasks automatically.',
     'jobscript':
         'cylc jobscript has been removed',
     'nudge':
@@ -249,7 +288,9 @@ DEAD_ENDS = {
     'register':
         'cylc register has been removed; use cylc install or cylc play',
     'reset':
-        'cylc reset has been replaced by cylc set-outputs',
+        'cylc reset has been replaced by cylc set',
+    'set-outputs':
+        'cylc set-outputs (cylc 8.0-8.2) has been replaced by cylc set',
     'restart':
         'cylc run & cylc restart have been replaced by cylc play',
     'review':
@@ -267,13 +308,15 @@ DEAD_ENDS = {
         'cylc submit has been removed',
     'start':
         'cylc start & cylc restart have been replaced by cylc play',
+    'set-verbosity':
+        'cylc set-verbosity has been replaced by cylc verbosity',
     'warranty':
         'cylc warranty has been replaced by cylc help license',
 }
 # fmt: on
 
 
-def execute_cmd(cmd: str, *args: str) -> NoReturn:
+def execute_cmd(cmd: str, *args: str) -> int:
     """Execute a sub-command.
 
     Args:
@@ -281,14 +324,14 @@ def execute_cmd(cmd: str, *args: str) -> NoReturn:
         args: Command line arguments to pass to that command.
 
     """
-    entry_point: pkg_resources.EntryPoint = COMMANDS[cmd]
+    entry_point = COMMANDS[cmd]
     try:
-        entry_point.resolve()(*args)
+        entry_point.load()(*args)
     except ModuleNotFoundError as exc:
         msg = handle_missing_dependency(entry_point, exc)
         print(msg, file=sys.stderr)
-        sys.exit(1)
-    sys.exit()
+        return 1
+    return 0
 
 
 def match_command(command):
@@ -376,7 +419,7 @@ def iter_commands() -> Iterator[Tuple[str, Optional[str], Optional[str]]]:
     """
     for cmd, entry_point in sorted(COMMANDS.items()):
         try:
-            module = __import__(entry_point.module_name, fromlist=[''])
+            module = __import__(entry_point.module, fromlist=[''])
         except ModuleNotFoundError as exc:
             handle_missing_dependency(entry_point, exc)
             continue
@@ -392,18 +435,10 @@ def print_id_help():
 
 
 def print_license() -> None:
-    try:
-        from importlib.metadata import files
-    except ImportError:
-        # BACK COMPAT: importlib_metadata
-        #   importlib.metadata was added in Python 3.8
-        # FROM: Python 3.7
-        # TO: Python: 3.8
-        from importlib_metadata import files  # type: ignore[no-redef]
-    license_file = next(filter(
-        lambda f: f.name == 'COPYING', files('cylc-flow')
-    ))
-    print(license_file.read_text())
+    for file in files('cylc-flow') or []:
+        if file.name == 'COPYING':
+            print(file.read_text())
+            return
 
 
 def print_command_list(commands=None, indent=0):
@@ -435,61 +470,62 @@ def cli_help():
     from colorama import init as color_init
     color_init(autoreset=True, strip=False)
     print(USAGE)
-    sys.exit(0)
 
 
 def cli_version(long_fmt=False):
     """Wrapper for get_version."""
     print(get_version(long_fmt))
     if long_fmt:
-        print(list_plugins())
-    sys.exit(0)
+        print(cparse(list_plugins()))
 
 
 def list_plugins():
-    entry_point_names = [
-        entry_point_name
-        for entry_point_name
-        in pkg_resources.get_entry_map('cylc-flow').keys()
-        if entry_point_name.startswith('cylc.')
-    ]
+    from cylc.flow.terminal import DIM, format_grid
+    # go through all Cylc entry points
+    _dists = set()
+    __entry_points = {}
+    for entry_point in entry_points():
+        if (
+            # all Cylc entry points are under the "cylc" namespace
+            entry_point.group.startswith('cylc.')
+            # don't list cylc-flow entry-points (i.e. built-ins)
+            and not entry_point.value.startswith('cylc.flow')
+        ):
+            _dists.add(entry_point.dist)
+            __entry_points.setdefault(
+                entry_point.group,
+                [],
+            ).append(entry_point)
 
-    entry_point_groups = {
-        entry_point_name: [
-            entry_point
-            for entry_point
-            in iter_entry_points(entry_point_name)
-            if not entry_point.module_name.startswith('cylc.flow')
-        ]
-        for entry_point_name in entry_point_names
-    }
+    # list all the distriutions which provide Cylc entry points
+    _plugins = []
+    for dist in _dists:
+        _plugins.append((
+            '',
+            f'<light-blue>{dist.name}</light-blue>',
+            dist.version,
+            f'<{DIM}>{dist.locate_file("__init__.py").parent}</{DIM}>',
+        ))
 
-    dists = {
-        entry_point.dist
-        for entry_points in entry_point_groups.values()
-        for entry_point in entry_points
-    }
+    # list all of the entry points by "group" (e.g. "cylc.command")
+    _entry_points = []
+    for group, points in sorted(__entry_points.items()):
+        _entry_points.append((f'  {group}:', '', ''))
+        for entry_point in points:
+            _entry_points.append((
+                f'    {entry_point.name}',
+                f'<light-blue>{entry_point.dist.name}</light-blue>',
+                f'<{DIM}>{entry_point.value}</{DIM}>',
+            ))
 
-    lines = []
-    if dists:
-        lines.append('\nPlugins:')
-        maxlen1 = max(len(dist.project_name) for dist in dists) + 2
-        maxlen2 = max(len(dist.version) for dist in dists) + 2
-        for dist in dists:
-            lines.append(
-                f'  {dist.project_name.ljust(maxlen1)}'
-                f' {dist.version.ljust(maxlen2)}'
-                f' {dist.module_path}'
-            )
-
-        lines.append('\nEntry Points:')
-        for entry_point_name, entry_points in entry_point_groups.items():
-            if entry_points:
-                lines.append(f'  {entry_point_name}:')
-                for entry_point in entry_points:
-                    lines.append(f'    {entry_point}')
-
-    return '\n'.join(lines)
+    return '\n'.join((
+        '\n<bold>Plugins:</bold>',
+        *format_grid(_plugins),
+        '\n<bold>Entry Points:</bold>',
+        *format_grid(
+            _entry_points
+        ),
+    ))
 
 
 @contextmanager
@@ -562,14 +598,14 @@ def pycoverage(cmd_args):  # pragma: no cover
             data_file=str(cylc_wc / '.coverage'),
             source=[str(cylc_wc / 'cylc')]
         )
-    except coverage.misc.CoverageException:
+    except coverage.misc.CoverageException as exc:
         raise Exception(
             # make sure this exception is visible in the traceback
             '\n\n*****************************\n\n'
             'Could not initiate coverage, likely because Cylc was not '
             'installed in editable mode.'
             '\n\n*****************************\n\n'
-        )
+        ) from exc
 
     # start the coverage running
     cov.start()
@@ -604,64 +640,74 @@ def get_arg_parser():
     return parser
 
 
-def main():
+def main() -> None:  # pragma: no cover
     opts, cmd_args = get_arg_parser().parse_known_args()
     with pycoverage(cmd_args):
-        if not cmd_args:
-            if opts.version:
-                cli_version()
-            else:
-                cli_help()
+        ret = _main(opts, cmd_args)
+    sys.exit(ret)
+
+
+def _main(opts, cmd_args) -> int:
+    """Implemnent the Cylc CLI.
+
+    Returns the exit code as an integer.
+    """
+    if not cmd_args:
+        if opts.version:
+            cli_version()
+            return 0
         else:
-            cmd_args = list(cmd_args)
-            command = cmd_args.pop(0)
+            cli_help()
+            return 0
+    else:
+        cmd_args = list(cmd_args)
+        command = cmd_args.pop(0)
 
-            if command == "version":
-                cli_version("--long" in cmd_args)
+        if command == "version":
+            cli_version("--long" in cmd_args)
+            return 0
 
-            if command == "help":
-                opts.help_ = True
-                if not len(cmd_args):
-                    cli_help()
-                elif cmd_args == ['all']:
-                    print_command_list()
-                    sys.exit(0)
-                elif cmd_args == ['id']:
-                    print_id_help()
-                    sys.exit(0)
-                if cmd_args in (['license'], ['licence']):
-                    print_license()
-                    sys.exit(0)
-                else:
-                    command = cmd_args.pop(0)
-
-            # this is an alias to a command
-            if command in ALIASES:
-                command = ALIASES.get(command)
-
-            if command in DEAD_ENDS:
-                # this command has been removed but not aliased
-                # display a helpful message and move on#
-                print(
-                    cparse(
-                        f'<red>{DEAD_ENDS[command]}</red>'
-                    )
-                )
-                sys.exit(42)
-
-            if command not in COMMANDS:
-                # check if this is a command abbreviation or exit
-                command = match_command(command)
-            if opts.help_:
-                execute_cmd(command, *cmd_args, "--help")
+        if command == "help":
+            opts.help_ = True
+            if not len(cmd_args):
+                cli_help()
+                return 0
+            elif cmd_args == ['all']:
+                print_command_list()
+                return 0
+            elif cmd_args == ['id']:
+                print_id_help()
+                return 0
+            if cmd_args in (['license'], ['licence']):
+                print_license()
+                return 0
             else:
-                if opts.version:
-                    cmd_args.append("--version")
-                execute_cmd(command, *cmd_args)
+                command = cmd_args.pop(0)
+
+        # this is an alias to a command
+        if command in ALIASES:
+            command = ALIASES.get(command)
+
+        if command in DEAD_ENDS:
+            # this command has been removed but not aliased
+            # display a helpful message and move on#
+            print(
+                cparse(
+                    f'<red>{DEAD_ENDS[command]}</red>'
+                )
+            )
+            return 42
+
+        if command not in COMMANDS:
+            # check if this is a command abbreviation or exit
+            command = match_command(command)
+        if opts.help_:
+            cmd_args.append('--help')
+        return execute_cmd(command, *cmd_args)
 
 
 def handle_missing_dependency(
-    entry_point: pkg_resources.EntryPoint,
+    entry_point,
     err: ModuleNotFoundError
 ) -> str:
     """Return a suitable error message for a missing optional dependency.
@@ -673,12 +719,8 @@ def handle_missing_dependency(
 
     Re-raises the given ModuleNotFoundError if it is unexpected.
     """
-    try:
-        # Check for missing optional dependencies
-        entry_point.require()
-    except pkg_resources.DistributionNotFound as exc:
-        # Confirmed missing optional dependencies
-        return f"cylc {entry_point.name}: {exc}"
-    else:
-        # Error not due to missing optional dependencies; this is unexpected
-        raise err
+    msg = f'"cylc {entry_point.name}" requires "{entry_point.dist.name}'
+    if entry_point.extras:
+        msg += f'[{",".join(entry_point.extras)}]'
+    msg += f'"\n\n{err.__class__.__name__}: {err}'
+    return msg
