@@ -14,14 +14,16 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""USAGE: cylc function-run <name> <json-args> <json-kwargs> <src-dir>
+"""USAGE: cylc function-run <module> <name> <json-args> <json-kwargs> <src-dir>
 
 (This command is for internal use.)
 
-Run a Python function "<name>(*args, **kwargs)" in the process pool. It must be
-defined in a module of the same name. Positional and keyword arguments must be
-passed in as JSON strings. <src-dir> is the workflow source dir, needed to find
-local xtrigger modules.
+Run a Python xtrigger function "<name>(*args, **kwargs)" in the process pool.
+Positional and keyword arguments must be passed in as JSON strings.
+
+Python entry points are the preferred way to make xtriggers available to the
+scheduler, but local xtriggers can be stored in <src-dir>.
+
 """
 import sys
 
@@ -35,7 +37,7 @@ def main(*api_args):
         args = [None] + list(api_args)
     else:
         args = sys.argv
-    if args[1] in ["help", "--help"] or len(args) != 5:
+    if args[1] in ["help", "--help"] or len(args) != 6:
         print(__doc__)
         sys.exit(0)
-    run_function(args[1], args[2], args[3], args[4])
+    run_function(*args[1:])
