@@ -15,34 +15,35 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""cylc tui WORKFLOW
+"""cylc tui [WORKFLOW]
 
 View and control running workflows in the terminal.
 
 (Tui = Terminal User Interface)
 
-WARNING: Tui is experimental and may break with large flows.
-An upcoming change to the way Tui receives data from the scheduler will make it
-much more efficient in the future.
+Tui allows you to monitor and interact with workflows in a manner similar
+to the GUI.
+
+Press "h" whilst running Tui to bring up the help screen, use the arrow
+keys to navigate.
+
 """
-# TODO: remove this warning once Tui is delta-driven
-# https://github.com/cylc/cylc-flow/issues/3527
 
+from getpass import getuser
 from textwrap import indent
-from typing import TYPE_CHECKING
-from urwid import html_fragment
+from typing import TYPE_CHECKING, Optional
 
+from cylc.flow.id import Tokens
 from cylc.flow.id_cli import parse_id
 from cylc.flow.option_parsers import (
-    WORKFLOW_ID_ARG_DOC,
+    OPT_WORKFLOW_ID_ARG_DOC,
     CylcOptionParser as COP,
 )
 from cylc.flow.terminal import cli_function
 from cylc.flow.tui import TUI
+from cylc.flow.tui.util import suppress_logging
 from cylc.flow.tui.app import (
     TuiApp,
-    TREE_EXPAND_DEPTH
-    # ^ a nasty solution
 )
 
 if TYPE_CHECKING:
@@ -55,57 +56,44 @@ __doc__ += indent(TUI, '           ')
 def get_option_parser() -> COP:
     parser = COP(
         __doc__,
-        argdoc=[WORKFLOW_ID_ARG_DOC],
+        argdoc=[OPT_WORKFLOW_ID_ARG_DOC],
         # auto_add=False,  NOTE: at present auto_add can not be turned off
         color=False
     )
 
     parser.add_option(
-        '--display',
+        '--comms-timeout',
+        metavar='SEC',
         help=(
-            'Specify the display technology to use.'
-            ' "raw" for interactive in-terminal display.'
-            ' "html" for non-interactive html output.'
+            # NOTE: Tui overrides the default client timeout
+            "Set the timeout for communication with the running workflow."
+            " The default is 5 seconds, you may need to increase this in"
+            " order for Tui to keep up with especially busy workflows."
         ),
         action='store',
-        choices=['raw', 'html'],
-        default='raw',
-    )
-    parser.add_option(
-        '--v-term-size',
-        help=(
-            'The virtual terminal size for non-interactive'
-            '--display options.'
-        ),
-        action='store',
-        default='80,24'
+        default=5,
+        dest='comms_timeout',
+        type=int,
     )
 
     return parser
 
 
 @cli_function(get_option_parser)
-def main(_, options: 'Values', workflow_id: str) -> None:
-    workflow_id, *_ = parse_id(
-        workflow_id,
-        constraint='workflows',
-    )
-    screen = None
-    if options.display == 'html':
-        TREE_EXPAND_DEPTH[0] = -1  # expand tree fully
-        screen = html_fragment.HtmlGenerator()
-        screen.set_terminal_properties(256)
-        screen.register_palette(TuiApp.palette)
-        html_fragment.screenshot_init(
-            [tuple(map(int, options.v_term_size.split(',')))],
-            []
+def main(_, options: 'Values', workflow_id: Optional[str] = None) -> None:
+    # get workflow ID if specified
+    if workflow_id:
+        workflow_id, *_ = parse_id(
+            workflow_id,
+            constraint='workflows',
         )
+        tokens = Tokens(workflow_id)
+        workflow_id = tokens.duplicate(user=getuser()).id
 
-    try:
-        TuiApp(workflow_id, screen=screen).main()
-
-        if options.display == 'html':
-            for fragment in html_fragment.screenshot_collect():
-                print(fragment)
-    except KeyboardInterrupt:
+    # start Tui
+    with suppress_logging(), TuiApp().main(
+        workflow_id,
+        client_timeout=options.comms_timeout,
+    ):
+        # tui stops according to user input
         pass
