@@ -442,12 +442,11 @@ class TaskPool:
             self._prev_runahead_sequence_points = sequence_points
             self._prev_runahead_base_point = base_point
 
-        if count_cycles:
-            if not sequence_points:
-                limit_point = base_point
-            else:
-                # (len(list) may be less than ilimit due to sequence end)
-                limit_point = sorted(sequence_points)[:ilimit + 1][-1]
+        if not sequence_points:
+            limit_point = base_point
+        elif count_cycles:
+            # (len(list) may be less than ilimit due to sequence end)
+            limit_point = sorted(sequence_points)[:ilimit + 1][-1]
         else:
             limit_point = max(sequence_points)
 
@@ -664,7 +663,7 @@ class TaskPool:
     def load_db_task_action_timers(self, row_idx: int, row: Iterable) -> None:
         """Load a task action timer, e.g. event handlers, retry states."""
         if row_idx == 0:
-            LOG.info("LOADING task action timers")
+            LOG.debug("LOADING task action timers")
         (cycle, name, ctx_key_raw, ctx_raw, delays_raw, num, delay,
          timeout) = row
         tokens = Tokens(
@@ -701,7 +700,7 @@ class TaskPool:
                 "%(id)s: skip action timer %(ctx_key)s" %
                 {"id": id_, "ctx_key": ctx_key_raw})
             return
-        LOG.info("+ %s/%s %s" % (cycle, name, ctx_key))
+        LOG.debug("+ %s/%s %s" % (cycle, name, ctx_key))
         if ctx_key == "poll_timer":
             itask = self._get_task_by_id(id_)
             if itask is None:
@@ -721,7 +720,7 @@ class TaskPool:
                     ctx_key[1] = TimerFlags.EXECUTION_RETRY
 
                 if timeout:
-                    LOG.info(
+                    LOG.debug(
                         f'  (upgrading retrying state for {itask.identity})')
                     self.task_events_mgr._retry_task(
                         itask,
@@ -901,8 +900,7 @@ class TaskPool:
         except KeyError:
             pass
         else:
-            with suppress(KeyError):
-                self.tasks_to_trigger_now.remove(itask)
+            self.tasks_to_trigger_now.discard(itask)
             self.tasks_removed = True
             self.active_tasks_changed = True
             if not self.active_tasks[itask.point]:
@@ -1043,7 +1041,7 @@ class TaskPool:
 
         return active_task_counter, pre_prep_tasks
 
-    def release_queued_tasks(self):
+    def release_queued_tasks(self) -> set['TaskProxy']:
         """Return list of queue-released tasks awaiting job prep.
 
         Note:
@@ -1072,7 +1070,7 @@ class TaskPool:
                 self.spawn_on_all_outputs(itask)
 
         # Note: released and pre_prep_tasks can overlap
-        return list(set(released + pre_prep_tasks))
+        return set(released + pre_prep_tasks)
 
     def get_min_point(self):
         """Return the minimum cycle point currently in the pool."""
