@@ -18,11 +18,13 @@
 
 from collections import deque
 from contextlib import suppress
-from typing import List, Set, Dict, Counter, Any
+from typing import TYPE_CHECKING, List, Set, Dict, Counter, Any
 
-from cylc.flow.task_proxy import TaskProxy
 from cylc.flow.task_queues import TaskQueueManagerBase
 
+if TYPE_CHECKING:
+    from cylc.flow.task_proxy import TaskProxy
+
 
 class LimitedTaskQueue:
     """One task queue with group members and active limit."""
@@ -33,16 +35,29 @@ class LimitedTaskQueue:
         self.members = members  # member task names
         self.deque: deque = deque()
 
-    def push_task(self, itask: TaskProxy) -> None:
+    def push_task(self, itask: 'TaskProxy') -> None:
         """Queue task if in my membership list."""
         if itask.tdef.name in self.members:
             self.deque.appendleft(itask)
 
-    def release(self, active: Counter[str]) -> List[TaskProxy]:
+    def push_task_if_limited(
+        self, itask: 'TaskProxy', active: Counter[str]
+    ) -> bool:
+        """Queue task if in my membership and the queue limit is reached."""
+        n_active = sum(active[mem] for mem in self.members)
+        if (
+            self.limit and n_active >= self.limit
+            and itask.tdef.name in self.members
+        ):
+            self.deque.appendleft(itask)
+            return True
+        return False
+
+    def release(self, active: Counter[str]) -> List['TaskProxy']:
         """Release tasks if below the active limit."""
         # The "active" argument counts active tasks by name.
-        released: List[TaskProxy] = []
-        held: List[TaskProxy] = []
+        released: List['TaskProxy'] = []
+        held: List['TaskProxy'] = []
         n_active: int = 0
         for mem in self.members:
             n_active += active[mem]
@@ -62,7 +77,7 @@ class LimitedTaskQueue:
             self.deque.appendleft(itask)
         return released
 
-    def remove(self, itask: TaskProxy) -> bool:
+    def remove(self, itask: 'TaskProxy') -> bool:
         """Remove a single task from queue, return True if removed."""
         try:
             self.deque.remove(itask)
@@ -111,36 +126,30 @@ class IndepQueueManager(TaskQueueManagerBase):
                 config["limit"], config["members"]
             )
 
-        self.force_released: Set[TaskProxy] = set()
-
-    def push_task(self, itask: TaskProxy) -> None:
+    def push_task(self, itask: 'TaskProxy') -> None:
         """Push a task to the appropriate queue."""
         for queue in self.queues.values():
             queue.push_task(itask)
 
-    def release_tasks(self, active: Counter[str]) -> List[TaskProxy]:
+    def push_task_if_limited(
+        self, itask: 'TaskProxy', active: Counter[str]
+    ) -> bool:
+        """Push a task to its queue only if the queue limit is reached."""
+        return any(
+            queue.push_task_if_limited(itask, active)
+            for queue in self.queues.values()
+        )
+
+    def release_tasks(self, active: Counter[str]) -> List['TaskProxy']:
         """Release tasks up to the queue limits."""
-        released: List[TaskProxy] = []
+        released: List['TaskProxy'] = []
         for queue in self.queues.values():
             released += queue.release(active)
-        if self.force_released:
-            released += list(self.force_released)
-            self.force_released = set()
         return released
 
-    def remove_task(self, itask: TaskProxy) -> None:
-        """Remove a task from whichever queue it belongs to."""
-        for queue in self.queues.values():
-            if queue.remove(itask):
-                break
-
-    def force_release_task(self, itask: TaskProxy) -> None:
-        """Remove a task from whichever queue it belongs to.
-
-        To be returned when release_tasks() is next called.
-        """
-        self.remove_task(itask)
-        self.force_released.add(itask)
+    def remove_task(self, itask: 'TaskProxy') -> bool:
+        """Try to remove a task from the queues. Return True if done."""
+        return any(queue.remove(itask) for queue in self.queues.values())
 
     def adopt_tasks(self, orphans: List[str]) -> None:
         """Adopt orphaned tasks to the default group."""
