@@ -60,7 +60,7 @@ def remove_keys_on_client(srvd, install_target, full_clean=False):
 
 
 def create_client_keys(srvd, install_target):
-    """Create or renew authentication keys for workflow 'reg' in the .service
+    """Create or renew authentication keys for workflow 'id_' in the .service
      directory.
      Generate a pair of ZMQ authentication keys"""
 
@@ -151,10 +151,11 @@ def remote_init(install_target: str, rund: str, *dirs_to_symlink: str) -> None:
         'job.sh',
         os.path.join(WorkflowFiles.Service.DIRNAME, 'etc')
     )
+    # Extract sent contact file from stdin:
     try:
-        tarhandle = tarfile.open(fileobj=sys.stdin.buffer, mode='r|')
-        tarhandle.extractall()
-        tarhandle.close()
+        with tarfile.open(fileobj=sys.stdin.buffer, mode='r|') as tarhandle:
+            tarhandle.extractall()  # nosec B202 - there should not be any
+            # untrusted members in the tar stream, only the contact file
     finally:
         os.chdir(oldcwd)
     print("KEYSTART", end='')
