@@ -1,5 +1,28 @@
+# THIS FILE IS PART OF THE CYLC WORKFLOW ENGINE.
+# Copyright (C) NIWA & British Crown (Met Office) & Contributors.
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+from typing import TYPE_CHECKING
+
 import pytest
 
+from cylc.flow import commands
+
+if TYPE_CHECKING:
+    from cylc.flow.scheduler import Scheduler
+
 
 @pytest.fixture
 def param_workflow(flow, scheduler):
@@ -64,13 +87,13 @@ async def test_queue_release(
         # (if scheduler is paused we should not have any submissions)
         # (otherwise a number of tasks up to the limit should be released)
         schd.pool.release_runahead_tasks()
-        schd.release_queued_tasks()
+        schd.release_tasks_to_run()
         assert len(submitted_tasks) == expected_submissions
 
         for _ in range(3):
             # release runahead/queued tasks
             # (no further tasks should be released)
-            schd.release_queued_tasks()
+            schd.release_tasks_to_run()
             assert len(submitted_tasks) == expected_submissions
 
 
@@ -86,7 +109,7 @@ async def test_queue_held_tasks(
 
     https://github.com/cylc/cylc-flow/issues/4628
     """
-    schd = param_workflow(paused_start=True, queue_limit=1)
+    schd: Scheduler = param_workflow(paused_start=True, queue_limit=1)
 
     async with start(schd):
         # capture task submissions (prevents real submissions)
@@ -97,18 +120,18 @@ async def test_queue_held_tasks(
 
         # hold all tasks and resume the workflow
         # (nothing should have run yet because the workflow started paused)
-        schd.command_hold('*/*')
+        await commands.run_cmd(commands.hold(schd, ['*/*']))
         schd.resume_workflow()
 
         # release queued tasks
         # (no tasks should be released from the queues because they are held)
-        schd.release_queued_tasks()
+        schd.release_tasks_to_run()
         assert len(submitted_tasks) == 0
 
         # un-hold tasks
-        schd.command_release('*/*')
+        await commands.run_cmd(commands.release(schd, ['*/*']))
 
         # release queued tasks
         # (tasks should now be released from the queues)
-        schd.release_queued_tasks()
+        schd.release_tasks_to_run()
         assert len(submitted_tasks) == 1
