@@ -15,8 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for the Cylc GlobalConfig object."""
 
-from pathlib import Path
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
@@ -25,6 +24,10 @@ from cylc.flow.parsec.exceptions import ValidationError
 from cylc.flow.parsec.validate import cylc_config_validate
 
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+
 TEST_CONF = '''
 [platforms]
     [[foo]]
@@ -39,7 +42,7 @@ TEST_CONF = '''
 
 
 @pytest.fixture
-def mock_global_config(tmp_path: Path, monkeypatch: pytest.MonkeyPatch):
+def mock_global_config(tmp_path: 'Path', monkeypatch: pytest.MonkeyPatch):
     """Create a mock GlobalConfig object, given the global.cylc contents as
     a string."""
     def _mock_global_config(cfg: str) -> GlobalConfig:
@@ -74,9 +77,19 @@ def test_dump_platform_details(capsys, mock_global_config):
     assert expected == out
 
 
-def test_expand_platforms(tmp_path: Path, mock_global_config: Callable):
-    """It should expand comma separated platform definitions."""
+def test_expand_commas(tmp_path: 'Path', mock_global_config: Callable):
+    """It should expand comma separated platform and install target
+    definitions."""
     glblcfg: GlobalConfig = mock_global_config('''
+    [install]
+        [[symlink dirs]]
+            [[[foo, bar]]]
+                run = /x
+            [[[foo]]]
+                share = /y
+            [[[bar]]]
+                share = /z
+
     [platforms]
         [[foo]]
             [[[meta]]]
@@ -91,7 +104,7 @@ def test_expand_platforms(tmp_path: Path, mock_global_config: Callable):
             [[[meta]]]
                 x = 4
     ''')
-    glblcfg._expand_platforms()
+    glblcfg._expand_commas()
 
     # ensure the definition order is preserved
     assert glblcfg.get(['platforms']).keys() == [
@@ -102,12 +115,18 @@ def test_expand_platforms(tmp_path: Path, mock_global_config: Callable):
         'pub',
     ]
 
-    # ensure sections are correctly deep-merged
+    # ensure platform sections are correctly deep-merged
     assert glblcfg.get(['platforms', 'foo', 'meta', 'x']) == '1'
     assert glblcfg.get(['platforms', 'bar', 'meta', 'x']) == '3'
     assert glblcfg.get(['platforms', 'baz', 'meta', 'x']) == '3'
     assert glblcfg.get(['platforms', 'pub', 'meta', 'x']) == '4'
 
+    # ensure install target sections are correctly merged:
+    assert glblcfg.get(["install", "symlink dirs", "foo", "run"]) == "/x"
+    assert glblcfg.get(["install", "symlink dirs", "foo", "share"]) == "/y"
+    assert glblcfg.get(["install", "symlink dirs", "bar", "run"]) == "/x"
+    assert glblcfg.get(["install", "symlink dirs", "bar", "share"]) == "/z"
+
 
 @pytest.mark.parametrize(
     'src_dir, err_expected',
@@ -136,7 +155,7 @@ def test_expand_platforms(tmp_path: Path, mock_global_config: Callable):
 )
 def test_source_dir_validation(
     src_dir: str, err_expected: bool,
-    tmp_path: Path, mock_global_config: Callable
+    tmp_path: 'Path', mock_global_config: Callable
 ):
     glblcfg: GlobalConfig = mock_global_config(f'''
     [install]
@@ -148,3 +167,49 @@ def test_source_dir_validation(
         assert "must be an absolute path" in str(excinfo.value)
     else:
         glblcfg.load()
+
+
+def test_platform_ssh_forward_variables(mock_global_config):
+
+    glblcfg: GlobalConfig = mock_global_config('''
+    [platforms]
+        [[foo]]
+            ssh forward environment variables = "FOO", "BAR"
+    ''')
+
+    assert glblcfg.get(
+        ['platforms', 'foo', 'ssh forward environment variables']
+    ) == ["FOO", "BAR"]
+
+
+def test_reload(
+    mock_global_config, tmp_path: 'Path', monkeypatch: pytest.MonkeyPatch
+):
+    # Load a config
+    glblcfg: GlobalConfig = mock_global_config('''
+    [platforms]
+        [[foo]]
+            [[[meta]]]
+                x = 1
+    ''')
+
+    # Update the global config file and reload
+    conf_path = tmp_path / GlobalConfig.CONF_BASENAME
+    conf_path.write_text('''
+    [platforms]
+        [[foo]]
+            [[[meta]]]
+                x = 2
+    ''')
+    glblcfg.load()
+
+    # Mock the global config singleton
+    monkeypatch.setattr(GlobalConfig, "get_inst", lambda *a, **k: glblcfg)
+
+    assert glblcfg.get(['platforms', 'foo', 'meta', 'x']) == '2'
+
+    from cylc.flow.platforms import get_platform
+
+    platform = get_platform("foo")
+
+    assert platform['meta']['x'] == "2"
