@@ -15,24 +15,26 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import jinja2
-
 import pytest
+import sys
 
-from cylc.flow.parsec.jinja2support import *
+from cylc.flow.parsec.jinja2support import (
+    Jinja2AssertionError,
+    Jinja2Error,
+    PyModuleLoader,
+    jinja2environment,
+    jinja2process,
+    assert_helper,
+    raise_helper,
+)
 
 
 def test_raise_helper():
     message = 'Ops'
-    error_type = 'CRITICAL'
-    with pytest.raises(Exception) as cm:
+    with pytest.raises(Jinja2AssertionError) as cm:
         raise_helper(message=message)
 
-    assert str(cm.value) == "Jinja2 Error: Ops"
-
-    with pytest.raises(Exception) as cm:
-        raise_helper(message=message, error_type=error_type)
-
-    assert str(cm.value) == "Jinja2 CRITICAL: Ops"
+    assert str(cm.value) == "Ops"
 
 
 def test_assert_helper():
