@@ -15,15 +15,18 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Unit Tests for cylc.flow.parsec.validate.ParsecValidator.coerce methods."""
 
+import logging
 from typing import List
 
+from cylc.flow import CYLC_LOG
 import pytest
-from pytest import approx
+from pytest import approx, param
 
 from cylc.flow.parsec.config import ConfigNode as Conf
 from cylc.flow.parsec.OrderedDict import OrderedDictWithDefaults
 from cylc.flow.parsec.exceptions import IllegalValueError
 from cylc.flow.parsec.validate import (
+    BroadcastConfigValidator,
     CylcConfigValidator as VDR,
     DurationFloat,
     ListValueError,
@@ -58,7 +61,6 @@ def sample_spec():
     return myconf
 
 
-@pytest.fixture
 def validator_invalid_values():
     """
     Data provider or invalid values for parsec validator. All values must not
@@ -93,7 +95,7 @@ def validator_invalid_values():
         Conf('value', VDR.V_INTEGER_LIST, default=1, options=[1, 2, 3, 4])
     cfg = OrderedDictWithDefaults()
     cfg['value'] = "1, 2, 5"
-    msg = '(type=option) value = [1, 2, 5]'
+    msg = '(type=option) value = 5'
     values.append((spec, cfg, msg))
 
     # set 3 (f, f, t, f)
@@ -236,21 +238,45 @@ def test_parsec_validator_invalid_key_with_many_spaces(sample_spec):
         assert str(cm.exception) == "section  3000000 - (consecutive spaces)"
 
 
+@pytest.mark.parametrize('spec, cfg, msg', validator_invalid_values())
 def test_parsec_validator_invalid_key_with_many_invalid_values(
-        validator_invalid_values
+    spec, cfg, msg
 ):
-    for spec, cfg, msg in validator_invalid_values:
-        parsec_validator = ParsecValidator()
-        if msg is not None:
-            with pytest.raises(IllegalValueError) as cm:
-                parsec_validator.validate(cfg, spec)
-            assert msg == str(cm.value)
-        else:
-            # cylc.flow.parsec_validator.validate(cfg, spec)
-            # let's use the alias `parsec_validate` here
-            parsec_validate(cfg, spec)
-            # TBD assertIsNotNone when 2.6+
-            assert parsec_validator is not None
+    parsec_validator = ParsecValidator()
+    if msg is not None:
+        with pytest.raises(IllegalValueError) as cm:
+            parsec_validator.validate(cfg, spec)
+        assert msg == str(cm.value)
+    else:
+        # cylc.flow.parsec_validator.validate(cfg, spec)
+        # let's use the alias `parsec_validate` here
+        parsec_validate(cfg, spec)
+        # TBD assertIsNotNone when 2.6+
+        assert parsec_validator is not None
+
+
+def test_parsec_validator_warn_options(caplog):
+    """Test the "warn_options" option.
+
+    This should turn invalid option errors into warnings.
+    """
+    with Conf('base') as spec:
+        Conf(
+            'foo',
+            VDR.V_STRING_LIST,
+            default=1,
+            options=['a', 'b'],
+            warn_options=True,
+        )
+
+    parsec_validator = ParsecValidator()
+    caplog.set_level(logging.WARNING, CYLC_LOG)
+    parsec_validator.validate({'foo': 'b, c'}, spec)
+
+    # there should be one (and only one) warning
+    assert caplog.messages == [
+        '(type=option) foo = c\nInvalid items have been removed'
+    ]
 
 
 def test_parsec_validator_invalid_key_with_many_1(sample_spec):
@@ -456,11 +482,9 @@ def test_coerce_int_list():
             validator.coerce_int_list(value, ['whatever'])
 
 
-def test_coerce_str():
-    """Test coerce_str."""
-    validator = ParsecValidator()
-    # The good
-    for value, result in [
+@pytest.mark.parametrize(
+    'value, expected',
+    [
         ('', ''),
         ('Hello World!', 'Hello World!'),
         ('"Hello World!"', 'Hello World!'),
@@ -474,9 +498,15 @@ def test_coerce_str():
          'Hello:\n    foo\nGreet\n    baz'),
         ('False', 'False'),
         ('None', 'None'),
-        (['a', 'b'], 'a\nb')
-    ]:
-        assert validator.coerce_str(value, ['whatever']) == result
+        (['a', 'b'], 'a\nb'),
+        ('abc#def', 'abc'),
+    ]
+)
+def test_coerce_str(value: str, expected: str):
+    """Test coerce_str."""
+    validator = ParsecValidator()
+    # The good
+    assert validator.coerce_str(value, ['whatever']) == expected
 
 
 def test_coerce_str_list():
@@ -498,9 +528,51 @@ def test_coerce_str_list():
         assert validator.coerce_str_list(value, ['whatever']) == results
 
 
-def test_strip_and_unquote():
+@pytest.mark.parametrize('value, expected', [
+    param(
+        "'a'",
+        'a',
+        id="single quotes"
+    ),
+    param(
+        '"\'a\'"',
+        "'a'",
+        id="single quotes inside double quotes"
+    ),
+    param(
+        '" a b" # comment',
+        ' a b',
+        id="comment outside"
+    ),
+    param(
+        '"""bene\ngesserit"""',
+        'bene\ngesserit',
+        id="multiline double quotes"
+    ),
+    param(
+        "'''kwisatz\n  haderach'''",
+        'kwisatz\n  haderach',
+        id="multiline single quotes"
+    ),
+    param(
+        '"""a\nb"""  # comment',
+        'a\nb',
+        id="multiline with comment outside"
+    ),
+])
+def test_unquote(value: str, expected: str):
+    """Test strip_and_unquote."""
+    assert ParsecValidator._unquote(['a'], value) == expected
+
+
+@pytest.mark.parametrize('value', [
+    '"""',
+    "'''",
+    "'don't do this'",
+])
+def test_strip_and_unquote__bad(value: str):
     with pytest.raises(IllegalValueError):
-        ParsecValidator.strip_and_unquote(['a'], '"""')
+        ParsecValidator.strip_and_unquote(['a'], value)
 
 
 def test_strip_and_unquote_list_parsec():
@@ -652,7 +724,7 @@ def test_coerce_parameter_list():
             ('-15, -10, -5, -1..1', [-15, -10, -5, -1, 0, 1])]:
         assert validator.coerce_parameter_list(value, ['whatever']) == result
     # The bad
-    for value in ['foo/bar', 'p1, 1..10', '2..3, 4, p']:
+    for value in ['foo/bar', 'p1, 1..10', '2..3, 4, p', 'x:,']:
         with pytest.raises(IllegalValueError):
             validator.coerce_parameter_list(value, ['whatever'])
 
@@ -691,4 +763,25 @@ def test_type_help_examples():
                     coercer(example, [None])
                 except Exception:
                     raise Exception(
-                        f'Example "{example}" failed for type "{vdr}"')
+                        f'Example "{example}" failed for type "{vdr}"'
+                    )
+
+
+@pytest.mark.parametrize(
+    'value, expected',
+    [
+        param(
+            """
+        a="don't have a cow"
+        a=${a#*have}
+        echo "$a" # let's see what happens
+        """,
+            "a=\"don't have a cow\"\na=${a#*have}\necho \"$a\""
+            " # let's see what happens",
+            id="multiline",
+        ),
+        param('"sleep 30 # ja!"  ', 'sleep 30 # ja!', id="quoted"),
+    ],
+)
+def test_broadcast_coerce_str(value: str, expected: str):
+    assert BroadcastConfigValidator.coerce_str(value, ['whatever']) == expected
