@@ -20,6 +20,7 @@ from cylc.flow.async_util import pipe
 from cylc.flow.id import Tokens
 from cylc.flow.network.scan import scan
 from cylc.flow.scripts.completion_server import (
+    _list_prereqs_and_outputs,
     server,
     complete_cylc,
     complete_command,
@@ -53,7 +54,6 @@ def setify(coro):
     Convenience function to use when you want to test output not order.
     """
     async def _coro(*args, **kwargs):
-        nonlocal coro
         ret = await coro(*args, **kwargs)
         if isinstance(ret, list):
             return set(ret)
@@ -85,7 +85,6 @@ def dummy_workflow(tmp_path, monkeypatch, mock_glbl_cfg):
     # patch scan for list_workflows
     @pipe
     async def _scan(*args, **kwargs):
-        nonlocal tmp_path
         kwargs['run_dir'] = tmp_path
         async for flow in scan(*args, **kwargs):
             yield flow
@@ -171,77 +170,80 @@ async def test_complete_cylc(dummy_workflow):
         'foo/run2//',
     }
 
-    # $ cylc triger f<tab><tab>
+    # $ cylc trigger f<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'f') == {
         'foo/run2//',
     }
 
-    # $ cylc triger foo/run2//<tab><tab>
+    # $ cylc trigger foo/run2//<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'foo/run2//') == {
         'foo/run2//1/',
         'foo/run2//2/',
         'foo/run2//3/',
     }
 
-    # $ cylc triger foo/run2//1<tab><tab>
+    # $ cylc trigger foo/run2//1<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'foo/run2//1') == {
         'foo/run2//1/',
     }
 
-    # $ cylc triger foo/run2//1/<tab><tab>
+    # $ cylc trigger foo/run2//1/<tab><tab>
     assert set(await _complete_cylc('cylc', 'trigger', 'foo/run2//1/')) == {
         'foo/run2//1/foo/',
         'foo/run2//1/bar/',
         'foo/run2//1/baz/',
     }
 
-    # $ cylc triger foo/run2//1/f<tab><tab>
+    # $ cylc trigger foo/run2//1/f<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'foo/run2//1/f') == {
         'foo/run2//1/foo/',
     }
 
-    # $ cylc triger foo/run2//1/foo/<tab><tab>
+    # $ cylc trigger foo/run2//1/foo/<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'foo/run2//1/foo/') == {
         'foo/run2//1/foo/01/',
         'foo/run2//1/foo/NN/',
     }
 
-    # $ cylc triger foo/run2//1/foo/N<tab><tab>
+    # $ cylc trigger foo/run2//1/foo/N<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', 'foo/run2//1/foo/N') == {
         'foo/run2//1/foo/NN/',
     }
 
-    # $ cylc triger -<tab><tab>
+    # $ cylc trigger -<tab><tab>
     assert '--flow' in await _complete_cylc('cylc', 'trigger', '-')
 
-    # $ cylc triger --flow <tab><tab>
+    # $ cylc trigger --flow <tab><tab>
     assert await _complete_cylc('cylc', 'trigger', '--flow', '') == {
-        'all',
         'none',
         'new',
     }
 
-    # $ cylc triger --flow <tab><tab>
-    assert await _complete_cylc('cylc', 'trigger', '--flow', 'all', '') == {
+    # $ cylc trigger --flow <tab><tab>
+    assert await _complete_cylc('cylc', 'trigger', '--flow', '', '') == {
         'foo/run2//'
     }
 
-    # $ cylc triger --flow=<tab><tab>
+    # $ cylc trigger --flow=none <tab><tab>
+    assert await _complete_cylc('cylc', 'trigger', '--flow=none', '') == {
+        'foo/run2//'
+    }
+
+    # $ cylc trigger --flow=<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', '--flow=') == {
-        '--flow=all',
         '--flow=none',
         '--flow=new',
     }
 
-    # $ cylc triger --flow=all <tab><tab>
-    assert await _complete_cylc('cylc', 'trigger', '--flow=all', '') == {
+    # $ cylc trigger --flow=1 <tab><tab>
+    assert await _complete_cylc('cylc', 'trigger', '--flow=1', '') == {
         'foo/run2//'
     }
 
-    # $ cylc triger --62656566<tab><tab>
+    # $ cylc trigger --62656566<tab><tab>
     assert await _complete_cylc('cylc', 'trigger', '--62656566') == set()
 
-    # $ cylc triger 62656566 --77656C6C696E67746F6E<tab><tab>
+    # $ cylc trigger 62656566 --77656C6C696E67746F6E<tab><tab>
     assert await _complete_cylc(
         'cylc', '62656566', '--77656C6C696E67746F6E='
     ) == set()
@@ -287,7 +289,8 @@ async def test_complete_option():
     ret = await complete_option('626565662077656C6C696E67746F6E')
     assert ret == []
 
-    assert await complete_option('trigger', '--flow=a') == ['--flow=all']
+    assert await complete_option('trigger', '--flow=no') == ['--flow=none']
+    assert await complete_option('trigger', '--flow=ne') == ['--flow=new']
 
     # we should get None for no existent options, this enables use to fail
     # over to other completion methods
@@ -297,11 +300,9 @@ async def test_complete_option():
 async def test_option_value():
     """Test completion for values of --options of Cylc commands."""
     ret = await complete_option_value('trigger', '--flow')
-    assert 'all' in ret
     assert 'none' in ret
 
     ret = await complete_option_value('trigger', '--flow', 'a')
-    assert 'all' in ret
     assert 'none' not in ret
 
     # we should get None for no existent values, this enables use to fail
@@ -318,7 +319,6 @@ async def test_complete_argument(monkeypatch):
     # register two fake commands with their own special completions
     def _complete_arg(x):
         async def __complete_arg(*args):
-            nonlocal x
             return x
         return __complete_arg
 
@@ -398,18 +398,17 @@ def test_list_options(monkeypatch):
     assert list_options('zz9+za') == []
 
     # patch the logic to turn off the auto_add behaviour of CylcOptionParser
-    def _resolve():
-        def _parser_function():
-            parser = get_option_parser()
-            del parser.auto_add
-            return parser
-
-        return SimpleNamespace(parser_function=_parser_function)
-
-    monkeypatch.setattr(
-        COMMANDS['trigger'],
-        'resolve',
-        _resolve
+    class EntryPoint:
+        def load(self):
+            def _parser_function():
+                parser = get_option_parser()
+                del parser.auto_add
+                return parser
+            return SimpleNamespace(parser_function=_parser_function)
+    monkeypatch.setitem(
+        COMMANDS,
+        'trigger',
+        EntryPoint(),
     )
 
     # with auto_add turned off the --color option should be absent
@@ -541,7 +540,7 @@ async def test_list_dir(tmp_path, monkeypatch):
     # => list $PWD
     assert {
         str(path)
-        for path in await _list_dir(None, None)
+        for path in await _list_dir(None)
     } == {'x/'}
 
     # no trailing `/` at the end of the path
@@ -549,7 +548,7 @@ async def test_list_dir(tmp_path, monkeypatch):
     # => list the parent
     assert {
         str(path)
-        for path in await _list_dir(None, 'x')
+        for path in await _list_dir('x')
     } == {'x/'}
 
     # # trailing `/` at the end of the path
@@ -557,14 +556,14 @@ async def test_list_dir(tmp_path, monkeypatch):
     # # => list dir path
     assert {
         str(path)
-        for path in await _list_dir(None, 'x/')
+        for path in await _list_dir('x/')
     } == {'x/y/', 'x/z'}  # "y" is a dir, "z" is a file
 
     # listing a file
     # => noting to list, just return the file
     assert {
         str(path)
-        for path in await _list_dir(None, 'x/z/')
+        for path in await _list_dir('x/z/')
     } == {'x/z'}
 
     # --- absolute paths ---
@@ -575,7 +574,7 @@ async def test_list_dir(tmp_path, monkeypatch):
     assert {
         # '/'.join(path.rsplit('/', 2)[-2:])
         path.replace(str(tmp_path), '')
-        for path in await _list_dir(None, str(tmp_path / 'x'))
+        for path in await _list_dir(str(tmp_path / 'x'))
     } == {'/x/'}
 
     # trailing `/` at the end of the path
@@ -583,29 +582,29 @@ async def test_list_dir(tmp_path, monkeypatch):
     # => list dir path
     assert {
         path.replace(str(tmp_path), '')
-        for path in await _list_dir(None, str(tmp_path / 'x') + '/')
+        for path in await _list_dir(str(tmp_path / 'x') + '/')
     } == {'/x/y/', '/x/z'}  # "y" is a dir, "z" is a file
 
     # listing a file
     # => noting to list, just return the file
     assert {
         path.replace(str(tmp_path), '')
-        for path in await _list_dir(None, str(tmp_path / 'x' / 'z') + '/')
+        for path in await _list_dir(str(tmp_path / 'x' / 'z') + '/')
     } == {'/x/z'}
 
 
 async def test_list_flows():
     """Test listing values for the --flow option.
 
-    Currently this only provides the textural options i.e. it doesn't list
+    Currently this only provides the textual options i.e. it doesn't list
     "flows" running in a workflow, yet...
     """
-    assert 'all' in await list_flows(None, None)
+    assert 'none' in await list_flows(None)
 
 
 async def test_list_colours():
     """Test listing values for the --color option."""
-    assert 'always' in await list_colours(None, None)
+    assert 'always' in await list_colours(None)
 
 
 async def test_cli_detokenise():
@@ -674,7 +673,7 @@ def test_check_completion_script_compatibility(monkeypatch, capsys):
     # set the completion script compatibility range to >=1.0.0, <2.0.0
     monkeypatch.setattr(
         'cylc.flow.scripts.completion_server.REQUIRED_SCRIPT_VERSION',
-        'completion-script >=1.0.0, <2.0.0',
+        '>=1.0.0, <2.0.0',
     )
     monkeypatch.setattr(
         'cylc.flow.scripts.completion_server'
@@ -716,3 +715,18 @@ def test_check_completion_script_compatibility(monkeypatch, capsys):
     out, err = capsys.readouterr()
     assert not out  # never write to stdout
     assert not err
+
+
+async def test_prereqs_and_outputs():
+    """Test the error cases for listing task prereqs/outputs.
+
+    The success cases are tested in an integration test (requires a running
+    scheduler).
+    """
+    # if no tokens are provided, no prereqs or outputs are returned
+    assert await _list_prereqs_and_outputs([]) == ([], [])
+
+    # if an invalid workflow is provided, we can't list anything
+    assert await _list_prereqs_and_outputs(
+        [Tokens(workflow='no-such-workflow')]
+    ) == ([], [])
