@@ -30,6 +30,7 @@ from typing import (
     Tuple,
     Type,
 )
+from unittest.mock import Mock
 
 import pytest
 
@@ -263,14 +264,12 @@ def test_family_inheritance_and_quotes(
 
 
 @pytest.mark.parametrize(
-    ('cycling_type', 'scheduling_cfg', 'expected_icp', 'expected_eval_icp',
-     'expected_err'),
+    ('cycling_type', 'scheduling_cfg', 'expected_icp', 'expected_err'),
     [
         pytest.param(
             ISO8601_CYCLING_TYPE,
             {'initial cycle point': None},
             None,
-            None,
             (WorkflowConfigError, "requires an initial cycle point"),
             id="Lack of icp"
         ),
@@ -279,14 +278,12 @@ def test_family_inheritance_and_quotes(
             {'initial cycle point': None},
             '1',
             None,
-            None,
             id="Default icp for integer cycling type"
         ),
         pytest.param(
             INTEGER_CYCLING_TYPE,
             {'initial cycle point': "now"},
             None,
-            None,
             (PointParsingError, "invalid literal for int()"),
             id="Non-integer ICP for integer cycling type"
         ),
@@ -294,7 +291,6 @@ def test_family_inheritance_and_quotes(
             INTEGER_CYCLING_TYPE,
             {'initial cycle point': "20500808T0000Z"},
             None,
-            None,
             (PointParsingError, "invalid literal for int()"),
             id="More non-integer ICP for integer cycling type"
         ),
@@ -302,7 +298,6 @@ def test_family_inheritance_and_quotes(
             ISO8601_CYCLING_TYPE,
             {'initial cycle point': "1"},
             None,
-            None,
             (PointParsingError, "Invalid ISO 8601 date representation"),
             id="Non-ISO8601 ICP for ISO8601 cycling type"
         ),
@@ -310,10 +305,16 @@ def test_family_inheritance_and_quotes(
             ISO8601_CYCLING_TYPE,
             {'initial cycle point': 'now'},
             '20050102T0615+0530',
-            '20050102T0615+0530',
             None,
             id="ICP = now"
         ),
+        pytest.param(
+            ISO8601_CYCLING_TYPE,
+            {'initial cycle point': 'previous(T00)'},
+            '20050102T0000+0530',
+            None,
+            id="ICP = prev"
+        ),
         pytest.param(
             ISO8601_CYCLING_TYPE,
             {
@@ -322,7 +323,6 @@ def test_family_inheritance_and_quotes(
             },
             '20130101T0000+0530',
             None,
-            None,
             id="Constraints"
         ),
         pytest.param(
@@ -332,7 +332,6 @@ def test_family_inheritance_and_quotes(
                 'initial cycle point constraints': ['--01-19', '--01-21']
             },
             None,
-            None,
             (WorkflowConfigError, "does not meet the constraints"),
             id="Violated constraints"
         ),
@@ -342,7 +341,6 @@ def test_family_inheritance_and_quotes(
                 'initial cycle point': 'a',
             },
             None,
-            None,
             (WorkflowConfigError, 'Invalid ISO 8601 date representation: a'),
             id="invalid"
         ),
@@ -352,7 +350,6 @@ def test_process_icp(
     cycling_type: str,
     scheduling_cfg: Dict[str, Any],
     expected_icp: Optional[str],
-    expected_eval_icp: Optional[str],
     expected_err: Optional[Tuple[Type[Exception], str]],
     monkeypatch: pytest.MonkeyPatch, set_cycling_type: 'Fixture'
 ) -> None:
@@ -364,8 +361,6 @@ def test_process_icp(
         cycling_type: Workflow cycling type.
         scheduling_cfg: 'scheduling' section of workflow config.
         expected_icp: The expected icp value that gets set.
-        expected_eval_icp: The expected value of options.icp that gets set
-            (this gets stored in the workflow DB).
         expected_err: Exception class expected to be raised plus the message.
     """
     set_cycling_type(cycling_type, time_zone="+0530")
@@ -392,53 +387,66 @@ def test_process_icp(
         assert mocked_config.cfg[
             'scheduling']['initial cycle point'] == expected_icp
         assert str(mocked_config.initial_point) == expected_icp
-        eval_icp = mocked_config.evaluated_icp
-        if eval_icp is not None:
-            eval_icp = str(loader.get_point(eval_icp).standardise())
-        assert eval_icp == expected_eval_icp
 
 
 @pytest.mark.parametrize(
-    'startcp, starttask, expected, expected_err',
+    'cycling_type, options, expected, expected_err',
     [
         (
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(startcp='20210120T1700+0530'),
             '20210120T1700+0530',
             None,
-            '20210120T1700+0530',
-            None
         ),
         (
-            'now',
-            None,
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(startcp='now'),
             '20050102T0615+0530',
-            None
+            None,
         ),
         (
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(startcp='previous(T00)'),
+            '20050102T0000+0530',
             None,
-            None,
+        ),
+        (
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(startcp=None),
             '18990501T0000+0530',
-            None
-        ),
-        (
             None,
-            ['20090802T0615+0530/foo', '20090802T0515+0530/bar'],
-            '20090802T0515+0530',
-            None
         ),
         (
-            '20210120T1700+0530',
-            ['20090802T0615+0530/foo'],
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(
+                starttask=['20090802T0615+0530/foo', '20090802T0515+0530/bar']
+            ),
+            '20090802T0515+0530',
+            None,
+        ),
+        (
+            ISO8601_CYCLING_TYPE,
+            SimpleNamespace(
+                startcp='20210120T1700+0530',
+                starttask=['20090802T0615+0530/foo'],
+            ),
             None,
             (
                 InputError,
-                "--start-cycle-point and --start-task are mutually exclusive"
+                "--start-cycle-point and --start-task are mutually exclusive",
             ),
+        ),
+        (
+            INTEGER_CYCLING_TYPE,
+            SimpleNamespace(startcp='10'),
+            '10',
+            None,
         )
-    ]
+    ],
 )
 def test_process_startcp(
-    startcp: Optional[str],
-    starttask: Optional[str],
+    cycling_type: str,
+    options: SimpleNamespace,
     expected: str,
     expected_err: Optional[Tuple[Type[Exception], str]],
     monkeypatch: pytest.MonkeyPatch, set_cycling_type: 'Fixture'
@@ -449,14 +457,16 @@ def test_process_startcp(
     2005-01-02T06:15+0530
 
     Params:
-        startcp: The start cycle point given by cli option.
+        options: SimpleNamespace with startcp and starttask attributes.
         expected: The expected startcp value that gets set.
         expected_err: Expected exception.
     """
-    set_cycling_type(ISO8601_CYCLING_TYPE, time_zone="+0530")
-    mocked_config = SimpleNamespace(
+    set_cycling_type(cycling_type, time_zone='+0530')
+    mocked_config = Mock(
+        spec=WorkflowConfig,
+        cycling_type=cycling_type,
         initial_point='18990501T0000+0530',
-        options=SimpleNamespace(startcp=startcp, starttask=starttask),
+        options=options,
     )
     monkeypatch.setattr('cylc.flow.config.get_current_time_string',
                         lambda: '20050102T0615+0530')
