@@ -31,7 +31,6 @@ from cylc.flow import (
 )
 from cylc.flow.job_file import (
     JobFileWriter,
-    MAX_CYLC_TASK_DEPENDENCIES_LEN,
 )
 from cylc.flow.platforms import platform_from_name
 
@@ -52,7 +51,7 @@ def test_get_variable_value_definition(in_value, out_value):
     parameter environment templates are handled"""
     param_dict = {'i': 3}
     res = JobFileWriter._get_variable_value_definition(in_value, param_dict)
-    assert(out_value == res)
+    assert out_value == res
 
 
 @pytest.fixture
@@ -115,7 +114,7 @@ def test_write(fixture_get_platform):
         size_of_file = os.stat(local_job_file_path).st_size
         # This test only needs to check that the file is created and is
         # non-empty as each section is covered by individual unit tests.
-        assert(size_of_file > 10)
+        assert size_of_file > 10
 
     """Test the header is correctly written"""
 
@@ -139,7 +138,7 @@ def test_write(fixture_get_platform):
 
     with io.StringIO() as fake_file:
         JobFileWriter()._write_header(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 @pytest.mark.parametrize(
@@ -231,7 +230,7 @@ def test_write_directives(fixture_get_platform, job_conf: dict, expected: str):
         written"""
     with io.StringIO() as fake_file:
         JobFileWriter()._write_directives(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 @pytest.mark.parametrize(
@@ -252,7 +251,7 @@ def test_traps_for_each_job_runner(job_runner: str):
     with io.StringIO() as fake_file:
         JobFileWriter()._write_prelude(fake_file, job_conf)
         output = fake_file.getvalue()
-        assert("CYLC_FAIL_SIGNALS='EXIT ERR TERM XCPU" in output)
+        assert "CYLC_FAIL_SIGNALS='EXIT ERR TERM XCPU" in output
 
 
 @pytest.mark.parametrize(
@@ -302,7 +301,7 @@ def test_write_prelude(monkeypatch, fixture_get_platform, set_CYLC_ENV_NAME):
     with io.StringIO() as fake_file:
         # copyable environment variables
         JobFileWriter()._write_prelude(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_write_workflow_environment(fixture_get_platform, monkeypatch):
@@ -364,7 +363,7 @@ def test_write_script():
 
     with io.StringIO() as fake_file:
         JobFileWriter()._write_script(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_no_script_section_with_comment_only_script():
@@ -388,7 +387,7 @@ def test_no_script_section_with_comment_only_script():
         JobFileWriter()._write_script(fake_file, job_conf)
         blah = fake_file.getvalue()
         print(blah)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_write_task_environment():
@@ -398,7 +397,6 @@ def test_write_task_environment():
                 'export CYLC_TASK_COMMS_METHOD=ssh\n    '
                 'export CYLC_TASK_JOB="1/moo/01"\n    export '
                 'CYLC_TASK_NAMESPACE_HIERARCHY="baa moo"\n    export '
-                'CYLC_TASK_DEPENDENCIES="moo neigh quack"\n    export '
                 'CYLC_TASK_TRY_NUMBER=1\n    export '
                 'CYLC_TASK_FLOW_NUMBERS=1\n    export '
                 'CYLC_TASK_PARAM_duck="quack"\n    export '
@@ -418,7 +416,7 @@ def test_write_task_environment():
     }
     with io.StringIO() as fake_file:
         JobFileWriter()._write_task_environment(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_write_runtime_environment():
@@ -439,7 +437,7 @@ def test_write_runtime_environment():
     }
     with io.StringIO() as fake_file:
         JobFileWriter()._write_runtime_environment(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_write_epilogue():
@@ -454,7 +452,7 @@ def test_write_epilogue():
     job_conf = {'job_d': "1/moo/01"}
     with io.StringIO() as fake_file:
         JobFileWriter()._write_epilogue(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_write_global_init_scripts(fixture_get_platform):
@@ -477,7 +475,7 @@ def test_write_global_init_scripts(fixture_get_platform):
     ''')
     with io.StringIO() as fake_file:
         JobFileWriter()._write_global_init_script(fake_file, job_conf)
-        assert(fake_file.getvalue() == expected)
+        assert fake_file.getvalue() == expected
 
 
 def test_homeless_platform(fixture_get_platform):
@@ -536,47 +534,3 @@ def test_homeless_platform(fixture_get_platform):
         job_sh_txt = job_sh.read()
         if 'HOME' in job_sh_txt:
             raise Exception('$HOME found in job.sh\n{job_sh_txt}')
-
-
-def test_cylc_task_dependencies_length():
-    f"""Test CYLC_TASK_DEPENDENCIES variable toggle.
-
-    The CYLC_TASK_DEPENDENCIES variriable should only be exported if there are
-    { MAX_CYLC_TASK_DEPENDENCIES_LEN } or fewer dependencies.
-
-    See: https://github.com/cylc/cylc-flow/issues/5551
-
-    """
-    job_conf = {
-        'platform': {'communication method': 'zmq'},
-        'job_d': 'a/b/c',
-        'namespace_hierarchy': ['a', 'b'],
-        # the maximum permitted number of dependencies before the environment
-        # variable is omitted
-        'dependencies': ['a'] * (MAX_CYLC_TASK_DEPENDENCIES_LEN),
-        'try_num': 1,
-        'flow_nums': {1},
-        'param_var': {},
-        'work_d': 'b/c/d',
-    }
-
-    # write the job environment
-    with io.StringIO() as fake_file:
-        JobFileWriter()._write_task_environment(fake_file, job_conf)
-        output = fake_file.getvalue()
-
-    # assert the env var is exported
-    lines = [line.strip().split('=')[0] for line in output.splitlines()]
-    assert 'export CYLC_TASK_DEPENDENCIES' in lines
-
-    # add an extra dependency to push it over the limit
-    job_conf['dependencies'] += ['b']
-
-    # write the job environment
-    with io.StringIO() as fake_file:
-        JobFileWriter()._write_task_environment(fake_file, job_conf)
-        output = fake_file.getvalue()
-
-    # assert the env var is redacted
-    lines = [line.strip().split('=')[0] for line in output.splitlines()]
-    assert '# CYLC_TASK_DEPENDENCIES' in lines  # var should be commented out
