@@ -16,23 +16,30 @@
 #
 # Tests for the platform lookup.
 
-import pytest
-from typing import Any, Dict, List, Optional, Type
+from typing import (
+    Any,
+    Dict,
+    List,
+    Optional,
+)
 
+import pytest
+
+from cylc.flow.exceptions import (
+    GlobalConfigError,
+    PlatformLookupError,
+)
 from cylc.flow.parsec.OrderedDict import OrderedDictWithDefaults
 from cylc.flow.platforms import (
+    _platform_name_from_job_info,
+    _validate_single_host,
+    generic_items_match,
+    get_install_target_from_platform,
+    get_install_target_to_platforms_map,
     get_platform,
     get_platform_deprecated_settings,
     is_platform_definition_subshell,
-    platform_from_name, platform_name_from_job_info,
-    get_install_target_from_platform,
-    get_install_target_to_platforms_map,
-    generic_items_match,
-    _validate_single_host
-)
-from cylc.flow.exceptions import (
-    PlatformLookupError,
-    GlobalConfigError
+    platform_from_name,
 )
 from cylc.flow.run_modes import JOBLESS_MODES
 
@@ -270,11 +277,11 @@ def test_similar_but_not_exact_match():
     ]
 )
 def test_platform_name_from_job_info_basic(job, remote, returns):
-    assert platform_name_from_job_info(PLATFORMS, job, remote) == returns
+    assert _platform_name_from_job_info(PLATFORMS, job, remote) == returns
 
 
 def test_platform_name_from_job_info_evaluated_hostname():
-    result = platform_name_from_job_info(
+    result = _platform_name_from_job_info(
         PLATFORMS,
         {'batch system': 'background'},
         {'host': '$(cat tiddles)'},
@@ -294,7 +301,7 @@ def test_platform_name_from_job_info_ordered_dict_comparison():
     platform.defaults_['Made up key'] = {}
     platform.update(PLATFORMS['hpc1-bg'])
     platforms = {'hpc1-bg': platform, 'dobbie': PLATFORMS['sugar']}
-    assert platform_name_from_job_info(platforms, job, remote) == 'hpc1-bg'
+    assert _platform_name_from_job_info(platforms, job, remote) == 'hpc1-bg'
 
 
 # Cases where the error ought to be raised because no matching platform should
@@ -321,7 +328,7 @@ def test_platform_name_from_job_info_ordered_dict_comparison():
 )
 def test_reverse_PlatformLookupError(job, remote):
     with pytest.raises(PlatformLookupError):
-        platform_name_from_job_info(PLATFORMS, job, remote)
+        _platform_name_from_job_info(PLATFORMS, job, remote)
 
 
 # An example of a global config with two Spice systems available
@@ -359,7 +366,7 @@ def test_platform_name_from_job_info_two_spices(
         },
 
     }
-    assert platform_name_from_job_info(platforms, job, remote) == returns
+    assert _platform_name_from_job_info(platforms, job, remote) == returns
 
 
 # An example of two platforms with the same hosts and job runner settings
@@ -406,7 +413,7 @@ def test_platform_name_from_job_info_similar_platforms(
             'job runner': 'background'
         },
     }
-    assert platform_name_from_job_info(platforms, job, remote) == returns
+    assert _platform_name_from_job_info(platforms, job, remote) == returns
 
 
 # -----------------------------------------------------------------------------
@@ -424,9 +431,8 @@ def test_get_install_target_from_platform(platform, expected):
     assert get_install_target_from_platform(platform) == expected
 
 
-@pytest.mark.parametrize('quiet', [True, False])
 @pytest.mark.parametrize(
-    'platform_names, expected_map, expected_err',
+    'platform_names, expected_map',
     [
         (
             ['enterprise', 'stargazer'],
@@ -436,7 +442,6 @@ def test_get_install_target_from_platform(platform, expected):
                     PLATFORMS_TREK['stargazer']
                 ]
             },
-            None
         ),
         (
             ['enterprise', 'voyager', 'enterprise'],
@@ -448,40 +453,34 @@ def test_get_install_target_from_platform(platform, expected):
                     PLATFORMS_TREK['voyager']
                 ]
             },
-            None
         ),
         (
-            ['enterprise', 'discovery'],
-            None,
-            PlatformLookupError
-        )
+            ['enterprise', 'starkiller'],  # ignores non-existent platform
+            {
+                'picard': [
+                    PLATFORMS_TREK['enterprise']
+                ],
+            },
+        ),
     ]
 )
 def test_get_install_target_to_platforms_map(
-        platform_names: List[str],
-        expected_map: Dict[str, Any],
-        expected_err: Type[Exception],
-        quiet: bool,
-        monkeypatch: pytest.MonkeyPatch
+    platform_names: list[str],
+    expected_map: dict[str, Any],
+    monkeypatch: pytest.MonkeyPatch,
 ):
     """Test that get_install_target_to_platforms_map works as expected."""
     monkeypatch.setattr('cylc.flow.platforms.platform_from_name',
                         lambda x: platform_from_name(x, PLATFORMS_TREK))
 
-    if expected_err and not quiet:
-        with pytest.raises(expected_err):
-            get_install_target_to_platforms_map(platform_names)
-    elif expected_err and quiet:
-        # No error should be raised in quiet mode.
-        assert get_install_target_to_platforms_map(platform_names, quiet=quiet)
-    else:
-        result = get_install_target_to_platforms_map(platform_names)
-        # Sort the maps:
-        for _map in (result, expected_map):
-            for install_target in _map:
-                _map[install_target] = sorted(_map[install_target],
-                                              key=lambda k: k['name'])
-        assert result == expected_map
+    result = get_install_target_to_platforms_map(platform_names)
+    # Sort the maps:
+    for _map in (result, expected_map):
+        for install_target in _map:
+            _map[install_target] = sorted(
+                _map[install_target], key=lambda k: k['name']
+            )
+    assert result == expected_map
 
 
 @pytest.mark.parametrize('mode', sorted(JOBLESS_MODES))
