@@ -16,11 +16,14 @@
 """Tests for Cylc scheduler server."""
 
 import logging
-import socket
+from secrets import token_hex
 from time import time
 from types import SimpleNamespace
 from typing import List
-from unittest.mock import MagicMock, Mock
+from unittest.mock import (
+    MagicMock,
+    Mock,
+)
 
 import pytest
 
@@ -67,7 +70,7 @@ def test_check_startup_opts(
         mocked_scheduler.options = SimpleNamespace(**{opt: 'reload'})
         with pytest.raises(InputError) as excinfo:
             Scheduler._check_startup_opts(mocked_scheduler)
-        assert(err_msg.format(opt) in str(excinfo))
+        assert err_msg.format(opt) in str(excinfo)
 
 
 @pytest.mark.parametrize(
@@ -91,10 +94,10 @@ def test_should_auto_restart_now(
     assert Scheduler.should_auto_restart_now(mock_schd) == expected
 
 
-def test_release_queued_tasks__auto_restart():
-    """Test that Scheduler.release_queued_tasks() works as expected
+def test_release_tasks_to_run__auto_restart():
+    """Test that Scheduler.release_tasks_to_run() works as expected
     during auto restart."""
-    mock_schd = Mock(
+    mock_schd = MagicMock(
         auto_restart_time=(time() - 100),
         auto_restart_mode=AutoRestartMode.RESTART_NORMAL,
         is_paused=False,
@@ -107,24 +110,28 @@ def test_release_queued_tasks__auto_restart():
         options=RunOptions(),
         task_job_mgr=MagicMock()
     )
-    Scheduler.release_queued_tasks(mock_schd)
+    Scheduler.release_tasks_to_run(mock_schd)
     # Should not actually release any more tasks, just submit the
     # preparing ones
     mock_schd.pool.release_queued_tasks.assert_not_called()
-    mock_schd.task_job_mgr.submit_task_jobs.assert_called()
+
+    Scheduler.start_job_submission(mock_schd, mock_schd.pool.get_tasks())
+    mock_schd.submit_task_jobs.assert_called()
 
 
-def test_auto_restart_DNS_error(monkeypatch, caplog, log_filter):
+def test_auto_restart_DNS_error(mock_glbl_cfg, caplog, log_filter):
     """Ensure that DNS errors in host selection are caught."""
-    def _select_workflow_host(cached=False):
-        # fake a "get address info" error
-        # this error can occur due to an unknown host resulting from broken
-        # DNS or an invalid host name in the global config
-        raise socket.gaierror('elephant')
-
-    monkeypatch.setattr(
-        'cylc.flow.scheduler.select_workflow_host',
-        _select_workflow_host,
+    # fake a "get address info" error
+    # this error can occur due to an unknown host resulting from broken
+    # DNS or an invalid host name in the global config
+    hostname = f'elephant_{token_hex(4)}'
+    mock_glbl_cfg(
+        'cylc.flow.host_select.glbl_cfg',
+        f'''
+            [scheduler]
+                [[run hosts]]
+                    available = {hostname}
+        '''
     )
     schd = Mock(
         workflow='myworkflow',
@@ -133,7 +140,7 @@ def test_auto_restart_DNS_error(monkeypatch, caplog, log_filter):
     )
     caplog.set_level(logging.ERROR, CYLC_LOG)
     assert not Scheduler.workflow_auto_restart(schd, max_retries=2)
-    assert log_filter(caplog, contains='elephant')
+    assert log_filter(contains=hostname)
 
 
 def test_auto_restart_popen_error(monkeypatch, caplog, log_filter):
@@ -166,4 +173,4 @@ def test_auto_restart_popen_error(monkeypatch, caplog, log_filter):
     )
     caplog.set_level(logging.ERROR, CYLC_LOG)
     assert not Scheduler.workflow_auto_restart(schd, max_retries=2)
-    assert log_filter(caplog, contains='mystderr')
+    assert log_filter(contains='mystderr')
