@@ -29,49 +29,47 @@ from cylc.flow.workflow_events import (
 
 
 @pytest.mark.parametrize(
-    'key, expected, scheduler_mail_defined',
+    'key, workflow_cfg, glbl_cfg, expected',
     [
-        ('handlers', ['stall'], True),
-        ('hotel', None, True),
-        ('from', 'highway@mixture', True),
-        ('abort on workflow timeout', True, True),
-        ('handlers', ['stall'], False),
-        ('hotel', None, False),
-        ('abort on workflow timeout', True, False),
+        ('handlers', True, True, ['stall']),
+        ('handlers', False, True, None),
+        ('handlers', False, False, None),
+        ('mail events', True, True, []),
+        ('mail events', False, True, ['abort']),
+        ('mail events', False, False, None),
+        ('from', True, True, 'docklands@railway'),
+        ('from', False, True, 'highway@mixture'),
+        ('from', False, False, None),
+        ('abort on workflow timeout', True, True, True),
+        ('abort on workflow timeout', False, True, True),
+        ('abort on workflow timeout', False, False, False),
     ]
 )
 def test_get_events_handler(
-    mock_glbl_cfg, key, expected, scheduler_mail_defined
+    mock_glbl_cfg, key, workflow_cfg, glbl_cfg, expected
 ):
-    # It checks that method returns sensible answers.
-    if scheduler_mail_defined is True:
-        mock_glbl_cfg(
-            'cylc.flow.workflow_events.glbl_cfg',
+    """Test order of precedence for getting event handler configuration."""
+    mock_glbl_cfg(
+        'cylc.flow.workflow_events.glbl_cfg',
+        (
             '''
             [scheduler]
                 [[mail]]
                     from = highway@mixture
                 [[events]]
                     abort on workflow timeout = True
+                    mail events = abort
             '''
-        )
-    else:
-        mock_glbl_cfg(
-            'cylc.flow.workflow_events.glbl_cfg',
-            '''
-            [scheduler]
-                [[events]]
-                    abort on workflow timeout = True
-            '''
-        )
+            if glbl_cfg else ''
+        ),
+    )
 
     config = SimpleNamespace()
     config.cfg = {
         'scheduler': {
-            'events': {
-                'handlers': ['stall']
-            },
-        }
+            'events': {'handlers': ['stall'], 'mail events': []},
+            'mail': {'from': 'docklands@railway'},
+        } if workflow_cfg else {'events': {}}
     }
     assert WorkflowEventHandler.get_events_conf(config, key) == expected
 
@@ -91,13 +89,13 @@ def test_process_mail_footer(caplog, log_filter):
     assert process_mail_footer(
         '%(host)s|%(port)s|%(owner)s|%(suite)s|%(workflow)s', template_vars
     ) == 'myhost|42|me|my_workflow|my_workflow\n'
-    assert not log_filter(caplog, contains='Ignoring bad mail footer template')
+    assert not log_filter(contains='Ignoring bad mail footer template')
 
     # test invalid variable
     assert process_mail_footer('%(invalid)s', template_vars) == ''
-    assert log_filter(caplog, contains='Ignoring bad mail footer template')
+    assert log_filter(contains='Ignoring bad mail footer template')
 
     # test broken template
     caplog.clear()
     assert process_mail_footer('%(invalid)s', template_vars) == ''
-    assert log_filter(caplog, contains='Ignoring bad mail footer template')
+    assert log_filter(contains='Ignoring bad mail footer template')
